@@ -111,6 +111,15 @@ SQLRETURN myodbc_do_connect(DBC *dbc, MYODBCUTIL_DATASOURCE *ds)
   options= strtoul(ds->pszOPTION, NULL, 10);
   port= (unsigned int)atoi(ds->pszPORT);
 
+#ifdef WIN32
+  /*
+   Detect if we are running with ADO present, and force on the
+   FLAG_COLUMN_SIZE_S32 option if we are.
+  */
+  if (GetModuleHandle("msado15.dll") != NULL)
+    options|= FLAG_COLUMN_SIZE_S32;
+#endif
+
   mysql_init(mysql);
 
   flags= get_client_flags(options);
@@ -134,11 +143,24 @@ SQLRETURN myodbc_do_connect(DBC *dbc, MYODBCUTIL_DATASOURCE *ds)
     mysql_options(mysql, MYSQL_OPT_CONNECT_TIMEOUT,
                   (char *)&dbc->login_timeout);
 
+  if (ds->pszREADTIMEOUT)
+  {
+    unsigned int to= strtoul(ds->pszREADTIMEOUT, NULL, 10);
+    mysql_options(mysql, MYSQL_OPT_READ_TIMEOUT, (const char *) &to);
+  }
+
+  if (ds->pszWRITETIMEOUT)
+  {
+    unsigned int to= strtoul(ds->pszWRITETIMEOUT, NULL, 10);
+    mysql_options(mysql, MYSQL_OPT_WRITE_TIMEOUT, (const char *) &to);
+  }
+
   /* set SSL parameters */
   mysql_ssl_set(mysql, ds->pszSSLKEY, ds->pszSSLCERT, ds->pszSSLCA,
                 ds->pszSSLCAPATH, ds->pszSSLCIPHER);
-  mysql_options(mysql, MYSQL_OPT_SSL_VERIFY_SERVER_CERT,
-                (const char *)&opt_ssl_verify_server_cert);
+  if (ds->pszSSLVERIFY)
+    mysql_options(mysql, MYSQL_OPT_SSL_VERIFY_SERVER_CERT,
+                  (const char *)&opt_ssl_verify_server_cert);
 
   if (!mysql_real_connect(mysql, ds->pszSERVER, ds->pszUSER, ds->pszPASSWORD,
                           ds->pszDATABASE, port, ds->pszSOCKET, flags))
@@ -181,10 +203,8 @@ SQLRETURN myodbc_do_connect(DBC *dbc, MYODBCUTIL_DATASOURCE *ds)
   dbc->port= port;
   dbc->flag= options;
 
-#ifdef MYODBC_DBG
   if (options & FLAG_LOG_QUERY && !dbc->query_log)
     dbc->query_log= init_query_log();
-#endif
 
   /* Set the statement error prefix based on the server version. */
   strxmov(dbc->st_error_prefix, MYODBC3_ERROR_PREFIX, "[mysqld-",
@@ -284,14 +304,11 @@ error:
 */
 SQLRETURN SQL_API SQLConnect(SQLHDBC  hdbc,
                              SQLCHAR *szDSN,  SQLSMALLINT cbDSN,
-                             SQLCHAR *szUID,
-                             SQLSMALLINT cbUID __attribute__((unused)),
-                             SQLCHAR *szAuth,
-                             SQLSMALLINT cbAuth __attribute__((unused)))
+                             SQLCHAR *szUID, SQLSMALLINT cbUID,
+                             SQLCHAR *szAuth, SQLSMALLINT cbAuth)
 {
   SQLRETURN rc;
   DBC *dbc= (DBC *)hdbc;
-  MYSQL *mysql= &dbc->mysql;
   char dsn[SQL_MAX_DSN_LENGTH], *dsn_ptr;
   MYODBCUTIL_DATASOURCE *ds;
 
@@ -317,9 +334,17 @@ SQLRETURN SQL_API SQLConnect(SQLHDBC  hdbc,
 
   /* Set username and password if they were provided. */
   if (szUID && szUID[0])
-    ds->pszUSER= _global_strdup((char *)szUID);
+  {
+    if (cbUID == SQL_NTS)
+      cbUID= strlen((char *)szUID);
+    ds->pszUSER= _global_strndup((char *)szUID, cbUID);
+  }
   if (szAuth && szAuth[0])
-    ds->pszPASSWORD= _global_strdup((char *)szAuth);
+  {
+    if (cbAuth == SQL_NTS)
+      cbAuth= strlen((char *)szAuth);
+    ds->pszPASSWORD= _global_strndup((char *)szAuth, cbAuth);
+  }
 
   /*
     We don't care if this fails, because we might be able to get away
@@ -375,6 +400,7 @@ SQLRETURN SQL_API SQLDriverConnect(SQLHDBC hdbc, SQLHWND hwnd,
   MYODBCUTIL_DRIVER *pDriver= MYODBCUtilAllocDriver();
   BOOL bPrompt= FALSE;
   HMODULE hModule= NULL;
+  unsigned long options;
 
   /* Parse the incoming string */
   if (!MYODBCUtilReadConnectStr(ds, (LPCSTR)szConnStrIn))
@@ -396,6 +422,14 @@ SQLRETURN SQL_API SQLDriverConnect(SQLHDBC hdbc, SQLHWND hwnd,
     (void)MYODBCUtilReadDataSource(ds, ds->pszDSN);
 #endif
 
+  /* If FLAG_NO_PROMPT is no set, force prompting off. */
+  if (ds->pszOPTION)
+  {
+    options= strtoul(ds->pszOPTION, NULL, 10);
+    if (options & FLAG_NO_PROMPT)
+      fDriverCompletion= SQL_DRIVER_NOPROMPT;
+  }
+
   /*
     We only prompt if we need to.
 
@@ -665,11 +699,10 @@ SQLRETURN SQL_API SQLDisconnect(SQLHDBC hdbc)
   my_free(dbc->password, MYF(0));
   dbc->dsn= dbc->database= dbc->server= dbc->user= dbc->password= 0;
 
-#ifdef MYODBC_DBG
   if (dbc->flag & FLAG_LOG_QUERY)
     end_query_log(dbc->query_log);
-#endif
 
   return SQL_SUCCESS;
 }
 
+
