@@ -424,13 +424,7 @@ static SQLRETURN copy_rowdata(STMT FAR *stmt, PARAM_BIND  param,
     /* We have to remove zero bytes or we have problems! */
     while ( (*to > orig_to) && (*((*to) - 1) == (SQLCHAR) 0) ) (*to)--;
 
-    /* insert "," */
-    param.SqlType= SQL_INTEGER;
-    param.CType= SQL_C_CHAR;
-    param.buffer= (gptr) ",";
-    *param.actual_len= 1;
-
-    if ( !(*to= (SQLCHAR*) insert_param(stmt->dbc,(char*) *to, &param)) )
+    if (!(*to= (SQLCHAR *)add_to_buffer(*net, (char *)*to, ",", 1)))
         return set_error(stmt,MYERR_S1001,NULL,4001);
 
     return(SQL_SUCCESS);
@@ -469,8 +463,6 @@ static SQLRETURN exec_stmt_query(STMT FAR *stmt,char *query,
 static SQLRETURN copy_field_data(STMT FAR *stmt, PARAM_BIND *param,
                                  NET **net, SQLCHAR **to)
 {
-    PARAM_BIND dummy;
-    SQLLEN     dummy_len= 5; /* sizeof(" AND ") */
     SQLUINTEGER length= *(param->actual_len)+5;
 
     if ( !(*to= (SQLCHAR*) extend_buffer(*net, (char*) *to,length)) )
@@ -480,12 +472,7 @@ static SQLRETURN copy_field_data(STMT FAR *stmt, PARAM_BIND *param,
         return set_error(stmt,MYERR_S1001,NULL,4001);
 
     /* Insert " AND ", where clause with multiple search */
-    dummy.SqlType= SQL_INTEGER;
-    dummy.CType= SQL_C_CHAR;
-    dummy.buffer= (gptr) " AND ";
-    dummy.actual_len= &dummy_len;
-
-    if ( !(*to= (SQLCHAR*) insert_param(stmt->dbc, (char*) *to, &dummy)) )
+    if (!(*to= (SQLCHAR *)add_to_buffer(*net, (char *)*to, " AND ", 5)))
         return set_error(stmt,MYERR_S1001,NULL,4001);
 
     return SQL_SUCCESS;
@@ -515,7 +502,7 @@ static my_bool insert_field(STMT FAR *stmt, MYSQL_RES *result,
 
     if ( row_data && *row_data )
     {
-        param.buffer= (gptr) *row_data;
+        param.buffer= *row_data;
         length= strlen(*row_data);
 
         param.actual_len= &length;
@@ -767,7 +754,7 @@ static void copy_input_param(STMT FAR *stmt,STMT FAR *stmtNew,
         PARAM_BIND *param= dynamic_element(&stmt->params,pcount,PARAM_BIND*);
         PARAM_BIND *paramNew= dynamic_element(&stmtNew->params,pcount,PARAM_BIND*);
         param->pos_in_query= paramNew->pos_in_query;
-        set_dynamic(&stmtNew->params,(gptr) param,pcount);
+        set_dynamic(&stmtNew->params, (DYNAMIC_ELEMENT)param, pcount);
     }
 }
 
@@ -838,7 +825,7 @@ static SQLRETURN build_set_clause(STMT FAR *stmt, SQLUINTEGER irow,
         param.used= 1;
         param.SqlType= get_sql_data_type(stmt, field, NULL);
         param.CType= bind->fCType;
-        param.buffer= (gptr) bind->rgbValue+irow*bind->cbValueMax;
+        param.buffer= ((char *)bind->rgbValue)+irow*bind->cbValueMax;
         param.ValueMax= bind->cbValueMax;
         /*
             Check when SQL_LEN_DATA_AT_EXEC() macro was used instead of data length
@@ -1154,7 +1141,7 @@ static SQLRETURN batch_insert( STMT FAR *stmt, SQLUSMALLINT irow, DYNAMIC_STRING
                   element_size= stmt->stmt_options.bind_type;
 
                 if (bind->pcbValue)
-                  ind_or_len= *(SQLLEN *)((gptr)bind->pcbValue +
+                  ind_or_len= *(SQLLEN *)((char *)bind->pcbValue +
                                           binding_offset +
                                           count * (element_size ?
                                                    element_size :
@@ -1164,7 +1151,7 @@ static SQLRETURN batch_insert( STMT FAR *stmt, SQLUSMALLINT irow, DYNAMIC_STRING
 
                 param.SqlType= get_sql_data_type(stmt, field, NULL);
                 param.CType = bind->fCType;
-                param.buffer= ((gptr)bind->rgbValue +
+                param.buffer= ((char *)bind->rgbValue +
                                binding_offset +
                                count * (element_size ?
                                         element_size :
@@ -1203,7 +1190,8 @@ static SQLRETURN batch_insert( STMT FAR *stmt, SQLUSMALLINT irow, DYNAMIC_STRING
               We have a limited capacity to shove data across the wire, but
               we handle this by sending in multiple calls to exec_stmt_query()
             */
-            if (ext_query->length + length >= (SQLLEN) net_buffer_length)
+            if ((size_t)ext_query->length + (size_t)length >=
+                (size_t)net_buffer_length)
             {
                 break_insert= TRUE;
                 break;
@@ -1440,7 +1428,7 @@ SQLRETURN SQL_API SQLSetCursorName(SQLHSTMT hstmt, SQLCHAR *szCursor,
          (myodbc_casecmp((char*) szCursor, "SQL_CUR", 7) == 0) )
         return set_error(stmt,MYERR_34000,NULL,0);
 
-    x_free((gptr) stmt->cursor.name);
+    x_free(stmt->cursor.name);
     stmt->cursor.name= dupp_str((char*) szCursor,cbCursor);
     return SQL_SUCCESS;
 }
@@ -1477,7 +1465,7 @@ SQLRETURN SQL_API SQLGetCursorName(SQLHSTMT hstmt, SQLCHAR FAR *szCursor,
     if ( szCursor && cbCursorMax > 0 )
         strmake((char*) szCursor, stmt->cursor.name, cbCursorMax);
 
-    nLength= min(*pcbCursor , cbCursorMax);
+    nLength= myodbc_min(*pcbCursor , cbCursorMax);
 
     if ( nLength != *pcbCursor )
         return set_error(stmt,MYERR_01004,NULL,0);
