@@ -225,6 +225,9 @@ void translate_error(char *save_state,myodbc_errid errid,uint mysql_err)
             state= "3D000";
             break;
         case ER_PARSE_ERROR:
+#ifdef ER_SP_DOES_NOT_EXIST
+        case ER_SP_DOES_NOT_EXIST:
+#endif
             state= myodbc3_errors[MYERR_42000].sqlstate;
             break;
         case ER_TABLE_EXISTS_ERROR:
@@ -248,6 +251,8 @@ void translate_error(char *save_state,myodbc_errid errid,uint mysql_err)
             break;
         case CR_SERVER_HANDSHAKE_ERR:
         case CR_CONNECTION_ERROR:
+        case CR_SERVER_GONE_ERROR:
+        case CR_SERVER_LOST:
             state= "08S01";
             break;
         default: break;
