@@ -52,8 +52,8 @@ SQLRETURN do_query(STMT FAR *stmt,char *query)
     if ( !query )
         return error;       /* Probably error from insert_param */
 
-    if ( stmt->stmt_options.max_rows && stmt->stmt_options.max_rows !=
-         (SQLINTEGER) ~0L )
+    if (stmt->stmt_options.max_rows &&
+        stmt->stmt_options.max_rows != (SQLULEN)~0L)
     {
         /* Add limit to select statement */
         char *pos,*tmp_buffer;
@@ -67,7 +67,7 @@ SQLRETURN do_query(STMT FAR *stmt,char *query)
                 sprintf(tmp_buffer+length, " limit %lu",
                         (unsigned long)stmt->stmt_options.max_rows);
                 if ( query != stmt->query )
-                    my_free((gptr) query,MYF(0));
+                    my_free(query,MYF(0));
                 query= tmp_buffer;
             }
         }
@@ -116,7 +116,7 @@ SQLRETURN do_query(STMT FAR *stmt,char *query)
     exit:
     pthread_mutex_unlock(&stmt->dbc->lock);
     if ( query != stmt->query )
-        my_free((gptr) query,MYF(0));
+        my_free(query,MYF(0));
 
     /*
       If the original query was modified, we reset stmt->query so that the
@@ -124,7 +124,7 @@ SQLRETURN do_query(STMT FAR *stmt,char *query)
     */
     if (stmt->orig_query)
     {
-        my_free((gptr) stmt->query,MYF(0));
+        my_free(stmt->query,MYF(0));
         stmt->query= stmt->orig_query;
         stmt->query_end= stmt->orig_query_end;
         stmt->orig_query= NULL;
@@ -189,7 +189,7 @@ char *insert_params(STMT FAR *stmt)
     net= &stmt->dbc->mysql.net;
     to= (char*) net->buff;
     if ( !(stmt->dbc->flag & FLAG_NO_LOCALE) )
-        setlocale(LC_NUMERIC,"English");  /* force use of '.' as decimal point */
+      setlocale(LC_NUMERIC, "C");  /* force use of '.' as decimal point */
     for ( i= 0; i < stmt->param_count; i++ )
     {
         PARAM_BIND *param= dynamic_element(&stmt->params,i,PARAM_BIND*);
@@ -262,9 +262,17 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
             else if ( param->ValueMax )
             {
 #ifndef strnlen
-                length=strlen(data);
-                if ( length > param->ValueMax )
-                    length = param->ValueMax;
+                length= strlen(data);
+                /* 
+                  For safety reasons add checking for SQL_SETPARAM_VALUE_MAX (-1)
+                  The negative length can be passed through the deprecated 
+                  function SQLSetParam 
+                */
+                if (param->ValueMax != SQL_SETPARAM_VALUE_MAX && 
+                    length > param->ValueMax)
+                {
+                  length= param->ValueMax;
+                }
 #else
                 length=strnlen(data,param->ValueMax);
 #endif
@@ -285,8 +293,12 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
       We may see SQL_COLUMN_IGNORE from bulk INSERT operations, where we
       may have been told to ignore a column in one particular row. So we
       try to insert DEFAULT, or NULL for really old servers.
+      In case there are less parameters than result columns we have to
+      insert NULL or DEFAULT.
     */
-    else if ( *(param->actual_len) == SQL_COLUMN_IGNORE )
+    else if (*(param->actual_len) == SQL_COLUMN_IGNORE ||
+             (*(param->actual_len) == 0 && param->CType == 0 && 
+              param->buffer == NULL))
     {
       if (is_minimum_version(dbc->mysql.server_version, "4.0.3", 5))
         return add_to_buffer(net,to,"DEFAULT",7);
@@ -405,6 +417,7 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
                 break;
             }
     }
+
     switch ( param->SqlType )
     {
         case SQL_DATE:
@@ -413,7 +426,7 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
         case SQL_TIMESTAMP:
             if ( data[0] == '{' )       /* Of type {d date } */
                 return add_to_buffer(net,to,data,length);
-            /* else threat as a string */
+            /* else treat as a string */
         case SQL_CHAR:
         case SQL_VARCHAR:
         case SQL_LONGVARCHAR:
@@ -423,15 +436,8 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
         case SQL_WCHAR:
         case SQL_WVARCHAR:
         case SQL_WLONGVARCHAR:
-            {
-              to= add_to_buffer(net,to,"'",1);
-              /* Make sure we have room for a fully-escaped string. */
-              if (!(to= extend_buffer(net, to, length * 2)))
-                return 0;
-              to+= mysql_real_escape_string(&dbc->mysql, to, data, length);
-              to= add_to_buffer(net, to, "'", 1);
-              return to;
-            }
+            break;
+
         case SQL_TIME:
         case SQL_TYPE_TIME:
             if ( param->CType == SQL_C_TIMESTAMP ||
@@ -473,11 +479,23 @@ char *insert_param(DBC *dbc, char *to,PARAM_BIND *param)
                 if ( to == buff )
                     *to++='0';    /* Fix for empty strings */
                 data= buff; length= (uint) (to-buff);
+
+                convert= 0;
+
             }
             /* Fall through */
         default:
+          if (!convert)
             return add_to_buffer(net,to,data,length);
     }
+
+    to= add_to_buffer(net,to,"'",1);
+    /* Make sure we have room for a fully-escaped string. */
+    if (!(to= extend_buffer(net, to, length * 2)))
+      return 0;
+    to+= mysql_real_escape_string(&dbc->mysql, to, data, length);
+    to= add_to_buffer(net, to, "'", 1);
+    return to;
 }
 
 
@@ -750,7 +768,7 @@ SQLRETURN SQL_API SQLPutData( SQLHSTMT      hstmt,
         else
         {
             /* This should never happen */
-            gptr old_pos= param->value;
+            char *old_pos= param->value;
             if ( !(param->value= my_malloc(param->value_length+cbValue+1,MYF(0))) )
                 return set_error(stmt,MYERR_S1001,NULL,4001);
             memcpy(param->value,old_pos,param->value_length);
