@@ -307,10 +307,13 @@ SQLRETURN SQL_API my_SQLAllocStmt(SQLHDBC hdbc,SQLHSTMT FAR *phstmt)
 #endif /* IS UNIX */
     stmt= (STMT FAR*) *phstmt;
     stmt->dbc= dbc;
+    pthread_mutex_lock(&stmt->dbc->lock);
     dbc->statements= list_add(dbc->statements,&stmt->list);
+    pthread_mutex_unlock(&stmt->dbc->lock);
     stmt->list.data= stmt;
     stmt->stmt_options= dbc->stmt_options;
     stmt->state= ST_UNKNOWN;
+    stmt->dummy_state= ST_DUMMY_UNKNOWN;
 #if !defined(DBUG_OFF) && defined(my_init_dynamic_array)
     my_init_dynamic_array(&stmt->params,sizeof(PARAM_BIND),32,64);
 #else
@@ -321,7 +324,7 @@ SQLRETURN SQL_API my_SQLAllocStmt(SQLHDBC hdbc,SQLHSTMT FAR *phstmt)
 
 
 /*
-  @type    : ODBC 1.0 APO
+  @type    : ODBC 1.0 API
   @purpose : allocates the statement handle
 */
 
@@ -423,11 +426,11 @@ SQLRETURN SQL_API my_SQLFreeStmtExtended(SQLHSTMT hstmt,SQLUSMALLINT fOption,
       }
     }
     else
-      x_free((gptr)stmt->result);
-    x_free((gptr) stmt->fields);
-    x_free((gptr) stmt->array);
-    x_free((gptr) stmt->result_array);
-    x_free((gptr) stmt->odbc_types);
+      x_free(stmt->result);
+    x_free(stmt->fields);
+    x_free(stmt->array);
+    x_free(stmt->result_array);
+    x_free(stmt->odbc_types);
     stmt->result= 0;
     stmt->fake_result= 0;
     stmt->result_lengths= 0;
@@ -444,7 +447,7 @@ SQLRETURN SQL_API my_SQLFreeStmtExtended(SQLHSTMT hstmt,SQLUSMALLINT fOption,
     if (fOption == MYSQL_RESET_BUFFERS)
         return SQL_SUCCESS;
 
-    x_free((gptr) stmt->table_name);
+    x_free(stmt->table_name);
     stmt->table_name= 0;
     stmt->dummy_state= ST_DUMMY_UNKNOWN;
     stmt->cursor.pk_validated= FALSE;
@@ -457,8 +460,8 @@ SQLRETURN SQL_API my_SQLFreeStmtExtended(SQLHSTMT hstmt,SQLUSMALLINT fOption,
         return SQL_SUCCESS;
 
     /* At this point, only MYSQL_RESET and SQL_DROP left out */
-    x_free((gptr) stmt->query);
-    x_free((gptr) stmt->orig_query);
+    x_free(stmt->query);
+    x_free(stmt->orig_query);
     stmt->query= stmt->orig_query= 0;
     stmt->param_count= 0;
 
@@ -467,10 +470,12 @@ SQLRETURN SQL_API my_SQLFreeStmtExtended(SQLHSTMT hstmt,SQLUSMALLINT fOption,
 
     odbc_reset_stmt_options(&stmt->stmt_options);
 
-    x_free((gptr) stmt->cursor.name);
-    x_free((gptr) stmt->bind);
+    x_free(stmt->cursor.name);
+    x_free(stmt->bind);
     delete_dynamic(&stmt->params);
+    pthread_mutex_lock(&stmt->dbc->lock);
     stmt->dbc->statements= list_delete(stmt->dbc->statements,&stmt->list);
+    pthread_mutex_unlock(&stmt->dbc->lock);
 #ifndef _UNIX_
     GlobalUnlock(GlobalHandle ((HGLOBAL) hstmt));
     GlobalFree(GlobalHandle((HGLOBAL) hstmt));
