@@ -288,12 +288,16 @@ SQLRETURN SQL_API SQLGetInfo(SQLHDBC hdbc, SQLUSMALLINT fInfoType,
   case SQL_SUBQUERIES:
   case SQL_TIMEDATE_ADD_INTERVALS:
   case SQL_TIMEDATE_DIFF_INTERVALS:
-  case SQL_UNION:
   case SQL_LOCK_TYPES:
     *((SQLUINTEGER *)rgbInfoValue)= 0L;
     *pcbInfoValue= sizeof(SQLUINTEGER);
     break;
 
+  case SQL_UNION:
+    *((SQLUINTEGER *)rgbInfoValue)= (SQL_U_UNION | SQL_U_UNION_ALL);
+    *pcbInfoValue= sizeof(SQLUINTEGER);
+    break;
+
     /* Un limit, set to default..*/
   case SQL_MAX_ASYNC_CONCURRENT_STATEMENTS:
   case SQL_MAX_BINARY_LITERAL_LEN:
@@ -363,6 +367,11 @@ SQLRETURN SQL_API SQLGetInfo(SQLHDBC hdbc, SQLUSMALLINT fInfoType,
     /* break; will never reach */
 
   case SQL_DATABASE_NAME:
+    if (reget_current_catalog(dbc))
+        return set_dbc_error(dbc, "HY000",
+                             "SQLGetInfo() failed to return current catalog.",
+                             0);
+
     MYINFO_SET_STR(rgbInfoValue, cbInfoValueMax, pcbInfoValue, dbc->database);
     /* break; will never reach */
 
@@ -503,9 +512,8 @@ SQLRETURN SQL_API SQLGetInfo(SQLHDBC hdbc, SQLUSMALLINT fInfoType,
     break;
 
   case SQL_GETDATA_EXTENSIONS:
-    *((SQLUINTEGER *)rgbInfoValue)= (SQL_GD_ANY_COLUMN |
-                                     SQL_GD_ANY_ORDER |
-                                     SQL_GD_BOUND);
+    *((SQLUINTEGER *)rgbInfoValue)= (SQL_GD_ANY_COLUMN | SQL_GD_BLOCK |
+                                     SQL_GD_ANY_ORDER | SQL_GD_BOUND);
     *pcbInfoValue= sizeof(SQLUINTEGER);
     break;
 
@@ -875,56 +883,31 @@ SQLRETURN SQL_API SQLGetInfo(SQLHDBC hdbc, SQLUSMALLINT fInfoType,
   Function sets up a result set containing details of the types
   supported by mysql.
 */
-#if MYSQL_VERSION_ID >= 40100
 MYSQL_FIELD SQL_GET_TYPE_INFO_fields[]=
 {
-  {"TYPE_NAME",         NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,32,32, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_VAR_STRING},
-  {"DATA_TYPE",         NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"COLUMN_SIZE",       NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,10,10, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_LONG},
-  {"LITERAL_PREFIX",    NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_VAR_STRING},
-  {"LITERAL_SUFFIX",    NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_VAR_STRING},
-  {"CREATE_PARAMS",     NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,15,15, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_VAR_STRING},
-  {"NULLABLE",          NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"CASE_SENSITIVE",    NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"SEARCHABLE",        NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"UNSIGNED_ATTRIBUTE",NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
-  {"FIXED_PREC_SCALE",  NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"AUTO_UNIQUE_VALUE", NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
-  {"LOCAL_TYPE_NAME",   NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,60,60, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_VAR_STRING},
-  {"MINIMUM_SCALE",     NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
-  {"MAXIMUM_SCALE",     NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
-  {"SQL_DATATYPE",      NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, NOT_NULL_FLAG,0,0,MYSQL_TYPE_SHORT},
-  {"SQL_DATETIME_SUB",  NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
-  {"NUM_PREC_RADIX",    NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,10,10, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_LONG},
-  {"INTERVAL_PRECISION",NullS,"GetTypeInfo",NullS,NullS,NullS,NullS,2,2, 0,0,0,0,0,0,0, 0,0,0,MYSQL_TYPE_SHORT},
+  MYODBC_FIELD_STRING("TYPE_NAME", 32, NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("DATA_TYPE", NOT_NULL_FLAG),
+  MYODBC_FIELD_LONG("COLUMN_SIZE", 0),
+  MYODBC_FIELD_STRING("LITERAL_PREFIX", 2, 0),
+  MYODBC_FIELD_STRING("LITERAL_SUFFIX", 1, 0),
+  MYODBC_FIELD_STRING("CREATE_PARAMS", 15, 0),
+  MYODBC_FIELD_SHORT("NULLABLE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("CASE_SENSITIVE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("SEARCHABLE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("UNSIGNED_ATTRIBUTE", 0),
+  MYODBC_FIELD_SHORT("FIXED_PREC_SCALE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("AUTO_UNIQUE_VALUE", 0),
+  MYODBC_FIELD_STRING("LOCAL_TYPE_NAME", 60, 0),
+  MYODBC_FIELD_SHORT("MINIMUM_SCALE", 0),
+  MYODBC_FIELD_SHORT("MAXIMUM_SCALE", 0),
+  MYODBC_FIELD_SHORT("SQL_DATATYPE", NOT_NULL_FLAG),
+  MYODBC_FIELD_SHORT("SQL_DATETIME_SUB", 0),
+  MYODBC_FIELD_LONG("NUM_PREC_RADIX", 0),
+  MYODBC_FIELD_SHORT("INTERVAL_PRECISION", 0),
 };
-#else
-MYSQL_FIELD SQL_GET_TYPE_INFO_fields[]=
-{
-  {"TYPE_NAME",         "GetTypeInfo",NullS,NullS,NullS,32,32,NOT_NULL_FLAG,0,MYSQL_TYPE_VAR_STRING},
-  {"DATA_TYPE",         "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"COLUMN_SIZE",       "GetTypeInfo",NullS,NullS,NullS,10,10,0,0,MYSQL_TYPE_LONG},
-  {"LITERAL_PREFIX",    "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_VAR_STRING},
-  {"LITERAL_SUFFIX",    "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_VAR_STRING},
-  {"CREATE_PARAMS",     "GetTypeInfo",NullS,NullS,NullS,15,15, 0,0,MYSQL_TYPE_VAR_STRING},
-  {"NULLABLE",          "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"CASE_SENSITIVE",    "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"SEARCHABLE",        "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"UNSIGNED_ATTRIBUTE","GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-  {"FIXED_PREC_SCALE",  "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"AUTO_UNIQUE_VALUE", "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-  {"LOCAL_TYPE_NAME",   "GetTypeInfo",NullS,NullS,NullS,60,60,0,0,MYSQL_TYPE_VAR_STRING},
-  {"MINIMUM_SCALE",     "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-  {"MAXIMUM_SCALE",     "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-  {"SQL_DATATYPE",      "GetTypeInfo",NullS,NullS,NullS,2,2,NOT_NULL_FLAG,0,MYSQL_TYPE_SHORT},
-  {"SQL_DATETIME_SUB",  "GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-  {"NUM_PREC_RADIX",    "GetTypeInfo",NullS,NullS,NullS,10,10,0,0,MYSQL_TYPE_LONG},
-  {"INTERVAL_PRECISION","GetTypeInfo",NullS,NullS,NullS,2,2,0,0,MYSQL_TYPE_SHORT},
-};
-#endif
 
 const uint SQL_GET_TYPE_INFO_FIELDS= array_elements(SQL_GET_TYPE_INFO_fields);
-#define MYSQL_DATA_TYPES 53
+#define MYSQL_DATA_TYPES 52
 
 char sql_searchable[6], sql_unsearchable[6], sql_nullable[6], sql_no_nulls[6],
      sql_bit[6], sql_tinyint[6], sql_smallint[6], sql_integer[6], sql_bigint[6],
@@ -936,8 +919,7 @@ char sql_searchable[6], sql_unsearchable[6], sql_nullable[6], sql_no_nulls[6],
 char *SQL_GET_TYPE_INFO_values[MYSQL_DATA_TYPES][19]=
 {
   /* SQL_BIT= -7 */
-  {"bit",sql_bit,"1",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","char(1)",NULL,NULL,sql_bit,NULL,NULL,NULL},
-  {"bit auto_increment",sql_bit,"1",NULL,NULL,NULL,sql_no_nulls,"0",sql_searchable,"0","0","1","char(1) auto_increment",NULL,NULL,sql_bit,NULL, NULL,NULL},
+  {"bit",sql_bit,"1",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"bit(1)",NULL,NULL,sql_bit,NULL,NULL,NULL},
 
   /* SQL_TINY= -6 */
   {"tinyint",sql_tinyint,"3",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","tinyint",NULL,NULL,sql_tinyint,NULL,"10",NULL},
@@ -952,28 +934,27 @@ char *SQL_GET_TYPE_INFO_values[MYSQL_DATA_TYPES][19]=
   {"bigint unsigned auto_increment",sql_bigint,"20",NULL,NULL,NULL,sql_no_nulls, "0",sql_searchable,"1","0","1","bigint unsigned auto_increment",NULL,NULL,sql_bigint, NULL,"10",NULL},
 
   /* SQL_LONGVARBINARY= -4 */
-  {"long varbinary",sql_longvarbinary,"16777215","0x",NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","mediumblob",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
-  {"blob",sql_longvarbinary,"65535","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","binary large object (0-65535)",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
-  {"longblob",sql_longvarbinary,"2147483647","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","binary large object, use mediumblob instead",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
-  {"tinyblob",sql_longvarbinary,"255","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","binary large object (0-255) ",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
-  {"mediumblob",sql_longvarbinary,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","binary large object",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
+  {"long varbinary",sql_longvarbinary,"16777215","0x",NULL,NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"mediumblob",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
+  {"blob",sql_longvarbinary,"65535","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"binary large object (0-65535)",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
+  {"longblob",sql_longvarbinary,"2147483647","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"binary large object, use mediumblob instead",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
+  {"tinyblob",sql_longvarbinary,"255","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"binary large object (0-255)",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
+  {"mediumblob",sql_longvarbinary,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"binary large object",NULL,NULL,sql_longvarbinary,NULL,NULL,NULL},
 
   /* SQL_VARBINARY= -3 */
-  {"varbinary",sql_varbinary,"255","'","'","length",sql_nullable,"0",sql_searchable,"0","0","0","varbinary",NULL,NULL,sql_varbinary,NULL,NULL,NULL},
+  {"varbinary",sql_varbinary,"255","'","'","length",sql_nullable,"0",sql_searchable,NULL,"0",NULL,"varbinary",NULL,NULL,sql_varbinary,NULL,NULL,NULL},
 
   /* SQL_BINARY= -2 */
-  {"binary",sql_binary,"255","'","'","length",sql_nullable,"0",sql_searchable,"0","0","0","binary",NULL,NULL,sql_binary,NULL,NULL,NULL},
-
+  {"binary",sql_binary,"255","'","'","length",sql_nullable,"0",sql_searchable,NULL,"0",NULL,"binary",NULL,NULL,sql_binary,NULL,NULL,NULL},
 
   /* SQL_LONGVARCHAR= -1 */
-  {"long varchar",sql_longvarchar,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","mediumtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
-  {"text",sql_longvarchar,"65535","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","text(0-65535)",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
-  {"mediumtext",sql_longvarchar,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","mediumtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
-  {"longtext",sql_longvarchar,"2147483647","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","longtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
-  {"tinytext",sql_longvarchar,"255","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","tinytext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
+  {"long varchar",sql_longvarchar,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"mediumtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
+  {"text",sql_longvarchar,"65535","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"text(0-65535)",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
+  {"mediumtext",sql_longvarchar,"16777215","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"mediumtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
+  {"longtext",sql_longvarchar,"2147483647","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"longtext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
+  {"tinytext",sql_longvarchar,"255","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"tinytext",NULL,NULL,sql_longvarchar,NULL,NULL,NULL},
 
   /* SQL_CHAR= 1 */
-  {"char",sql_char,"255","'","'","length",sql_nullable,"0",sql_searchable,"0","0","0","char",NULL,NULL,sql_char,NULL,NULL,NULL},
+  {"char",sql_char,"255","'","'","length",sql_nullable,"0",sql_searchable,NULL,"0",NULL,"char",NULL,NULL,sql_char,NULL,NULL,NULL},
 
   /* SQL_NUMERIC= 2 */
   {"numeric",sql_numeric,"19",NULL,NULL,"precision,scale",sql_nullable,"0",sql_searchable,"0","0","0","numeric","0","19",sql_numeric,NULL,"10",NULL},
@@ -1002,39 +983,34 @@ char *SQL_GET_TYPE_INFO_values[MYSQL_DATA_TYPES][19]=
   {"smallint unsigned auto_increment",sql_smallint,"5",NULL,NULL,NULL,sql_no_nulls, "0",sql_searchable,"1","0","1","smallint unsigned auto_increment",NULL,NULL, sql_smallint,NULL,"10",NULL},
 
   /* SQL_FLOAT= 6 */
-  {"double",sql_float,"15",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","double","0","4",sql_float, NULL,"2",NULL},
-  {"double auto_increment",sql_float,"15",NULL,NULL,NULL,sql_no_nulls,"0",sql_searchable,"0","0","1","double auto_increment","0","4",sql_float,NULL,"2",NULL},
+  {"double",sql_float,"15",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","double","0","4",sql_float, NULL,"10",NULL},
+  {"double auto_increment",sql_float,"15",NULL,NULL,NULL,sql_no_nulls,"0",sql_searchable,"0","0","1","double auto_increment","0","4",sql_float,NULL,"10",NULL},
 
   /* SQL_REAL= 7 */
-  {"float",sql_real,"7",NULL,NULL,NULL,sql_nullable, "0",sql_unsearchable,"0","0","0","float","0","2",sql_float, NULL,"10",NULL},
-  {"float auto_increment",sql_real,"7",NULL,NULL,NULL,sql_no_nulls,"0",sql_unsearchable,"0","0","1","float auto_increment","0","2",sql_float,NULL,"10",NULL},
+  {"float",sql_real,"7",NULL,NULL,NULL,sql_nullable, "0",sql_unsearchable,"0","0","0","float","0","2",sql_real, NULL,"10",NULL},
+  {"float auto_increment",sql_real,"7",NULL,NULL,NULL,sql_no_nulls,"0",sql_unsearchable,"0","0","1","float auto_increment","0","2",sql_real,NULL,"10",NULL},
 
   /* SQL_DOUBLE= 8 */
   {"double",sql_double,"15",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","double","0","4",sql_double,NULL,"10",NULL},
   {"double auto_increment",sql_double,"15",NULL,NULL,NULL,sql_no_nulls,"0",sql_searchable,"0","0","1","double auto_increment","0","4",sql_double,NULL,"10",NULL},
 
   /* SQL_TYPE_DATE= 91 */
-  {"date",sql_date,"10","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","date",NULL,NULL,sql_datetime,sql_date,NULL,NULL},
+  {"date",sql_date,"10","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"date",NULL,NULL,sql_datetime,sql_date,NULL,NULL},
 
   /* SQL_TYPE_TIME= 92 */
-  {"time",sql_time,"6","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","time",NULL,NULL,sql_datetime,sql_time,NULL,NULL},
+  {"time",sql_time,"8","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"time",NULL,NULL,sql_datetime,sql_time,NULL,NULL},
 
   /* YEAR - SQL_SMALLINT */
   {"year",sql_smallint,"4",NULL,NULL,NULL,sql_nullable,"0",sql_searchable,"0","0","0","year",NULL,NULL,sql_smallint,NULL,"10",NULL},
 
   /* SQL_TYPE_TIMESTAMP= 93 */
-  {"datetime",sql_timestamp,"21","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","datetime","0","0",sql_datetime,sql_timestamp,NULL,NULL},
-  {"timestamp",sql_timestamp,"14","'","'",NULL,sql_no_nulls,"0",sql_searchable,"0","0","0","timestamp","0","0",sql_datetime,sql_timestamp,NULL,NULL},
+  {"datetime",sql_timestamp,"21","'","'",NULL,sql_nullable,"0",sql_searchable,NULL,"0",NULL,"datetime","0","0",sql_datetime,sql_timestamp,NULL,NULL},
+  {"timestamp",sql_timestamp,"14","'","'",NULL,sql_no_nulls,"0",sql_searchable,NULL,"0",NULL,"timestamp","0","0",sql_datetime,sql_timestamp,NULL,NULL},
 
   /* SQL_VARCHAR= 12 */
-#if TO_BE_DELETED /* NO NEED OF THIS, causes problems for DM */
-  {"text",sql_varchar,"255","'","'","",sql_nullable,"0",sql_searchable,"0","0","0","text",NULL,NULL,sql_varchar,NULL,NULL,NULL},
-#endif
-  {"varchar",sql_varchar,"255","'","'","max length",sql_nullable,"0",sql_searchable,"0","0","0","varchar",NULL,NULL,sql_varchar,NULL,NULL,NULL},
-#if TO_BE_DELETED /* NO NEED OF THIS, causes problems for DM */
-  {"enum",sql_varchar,"255","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","enum(value1,value2,value3...)",NULL,NULL,sql_varchar,NULL,NULL,NULL},
-  {"set",sql_varchar,"255","'","'",NULL,sql_nullable,"0",sql_searchable,"0","0","0","set(value1,value2,value3...)",NULL,NULL,sql_varchar,NULL,NULL,NULL}
-#endif
+  {"varchar",sql_varchar,"255","'","'","length",sql_nullable,"0",sql_searchable,NULL,"0",NULL,"varchar",NULL,NULL,sql_varchar,NULL,NULL,NULL},
+
+  /* ENUM and SET are not included -- it confuses some applications. */
 };
 
 
@@ -1062,8 +1038,8 @@ SQLRETURN SQL_API SQLGetTypeInfo(SQLHSTMT hstmt, SQLSMALLINT fSqlType)
 
   if (fSqlType == SQL_ALL_TYPES)
   {
-    memcpy((byte *)stmt->result_array,
-           (byte *)SQL_GET_TYPE_INFO_values,
+    memcpy(stmt->result_array,
+           SQL_GET_TYPE_INFO_values,
            sizeof(SQL_GET_TYPE_INFO_values));
     stmt->result->row_count= MYSQL_DATA_TYPES;
   }
@@ -1074,9 +1050,9 @@ SQLRETURN SQL_API SQLGetTypeInfo(SQLHSTMT hstmt, SQLSMALLINT fSqlType)
       if (atoi(SQL_GET_TYPE_INFO_values[i][1]) == fSqlType ||
           atoi(SQL_GET_TYPE_INFO_values[i][15]) == fSqlType)
       {
-        memcpy((gptr)&stmt->result_array[stmt->result->row_count++ *
-                                         SQL_GET_TYPE_INFO_FIELDS],
-               (gptr)&SQL_GET_TYPE_INFO_values[i][0],
+        memcpy(&stmt->result_array[stmt->result->row_count++ *
+                                   SQL_GET_TYPE_INFO_FIELDS],
+               &SQL_GET_TYPE_INFO_values[i][0],
                sizeof(char *) * SQL_GET_TYPE_INFO_FIELDS);
       }
     }
@@ -1206,7 +1182,7 @@ SQLUSMALLINT myodbc3_functions[]=
     /* SQL_API_SQLSETDESCFIELD */
     /* SQL_API_SQLSETDESCREC */
     SQL_API_SQLSETENVATTR,
-    /* SQL_API_SQLSETPARAM */
+    SQL_API_SQLSETPARAM,
     SQL_API_SQLSETSTMTATTR,
     SQL_API_SQLSETSTMTOPTION,
     SQL_API_SQLSPECIALCOLUMNS,
@@ -1229,7 +1205,7 @@ SQLUSMALLINT myodbc3_functions[]=
     SQL_API_SQLNUMPARAMS,
     SQL_API_SQLPARAMOPTIONS,
     SQL_API_SQLPRIMARYKEYS,
-    /* SQL_API_SQLPROCEDURECOLUMNS, */
+    SQL_API_SQLPROCEDURECOLUMNS,
     SQL_API_SQLPROCEDURES,
     SQL_API_SQLSETPOS,
     SQL_API_SQLSETSCROLLOPTIONS,
@@ -1259,6 +1235,9 @@ SQLRETURN SQL_API SQLGetFunctions(SQLHDBC hdbc __attribute__((unused)),
 
   if (fFunction == SQL_API_ODBC3_ALL_FUNCTIONS)
   {
+    /* Clear and set bits in the 4000 bit vector */
+    memset(pfExists, 0,
+           sizeof(SQLUSMALLINT) * SQL_API_ODBC3_ALL_FUNCTIONS_SIZE);
     for (index= 0; index < myodbc_func_size; index++)
     {
       SQLUSMALLINT id= myodbc3_functions[index];
@@ -1269,6 +1248,8 @@ SQLRETURN SQL_API SQLGetFunctions(SQLHDBC hdbc __attribute__((unused)),
 
   if (fFunction == SQL_API_ALL_FUNCTIONS)
   {
+    /* Clear and set elements in the SQLUSMALLINT 100 element array */
+    memset(pfExists, 0, sizeof(SQLUSMALLINT) * 100);
     for (index= 0; index < myodbc_func_size; index++)
     {
       if (myodbc3_functions[index] < 100)
