@@ -42,6 +42,11 @@
 #define WIN32	/* Hack for rc files */
 #endif
 
+#ifndef myodbc_max
+#define myodbc_max( a, b ) (((a) > (b)) ? (a) : (b))
+#define myodbc_min( a, b ) (((a) < (b)) ? (a) : (b))
+#endif
+
 #ifdef __cplusplus
 extern "C"
 {
@@ -92,30 +97,20 @@ extern "C"
 #if defined(__APPLE__)
 
 #define DRIVER_DLL_NAME   "libmyodbc3.dylib"
-#ifdef MYODBC_DBG
 #define DRIVER_QUERY_LOGFILE "/tmp/myodbc.sql"
-#endif
 
 #elif defined(_UNIX_)
 
 #define DRIVER_DLL_NAME   "libmyodbc3.so"
-#ifdef MYODBC_DBG
 #define DRIVER_QUERY_LOGFILE "/tmp/myodbc.sql"
-#endif
 
 #else
 
 #define DRIVER_DLL_NAME   "myodbc3.dll"
-#ifdef MYODBC_DBG
 #define DRIVER_QUERY_LOGFILE "c:\\myodbc.sql"
-#endif
 
 #endif
 
-#ifdef MYODBC_DBG
-#define CHECK_EXTRA_ARGUMENTS
-#endif
-
 /*
    Internal driver definations
 */
@@ -136,9 +131,9 @@ extern "C"
 /*
   Connection parameters, that affects the driver behaviour
 */
-#define FLAG_FIELD_LENGTH	1   /* field_length instead of max_length */
+#define FLAG_FIELD_LENGTH	1   /* no longer used */
 #define FLAG_FOUND_ROWS		2   /* Access can't handle affected_rows */
-#define FLAG_DEBUG		4   /* Put a debug log on C:\myodbc.log */
+#define FLAG_DEBUG		4   /* no longer used */
 #define FLAG_BIG_PACKETS	8   /* Allow BIG packets. */
 #define FLAG_NO_PROMPT		16  /* Don't prompt on connection */
 #define FLAG_DYNAMIC_CURSOR	32  /* Enables the dynamic cursor */
@@ -165,6 +160,9 @@ extern "C"
 #define FLAG_ZERO_DATE_TO_MIN (1 << 24) /* Convert XXXX-00-00 date to ODBC min date on results */
 #define FLAG_MIN_DATE_TO_ZERO (1 << 25) /* Convert ODBC min date to 0000-00-00 on query */
 #define FLAG_MULTI_STATEMENTS (1 << 26) /* Allow multiple statements in a query */
+#define FLAG_COLUMN_SIZE_S32 (1 << 27) /* Limit column size to a signed 32-bit value (automatically set for ADO) */
+#define FLAG_NO_BINARY_RESULT (1 << 28) /* Disables charset 63 for columns with empty org_table */
+/* (1 << 29) is reserved for FLAG_DFLT_BIGINT_BIND_STR */
 
 /* We don't make any assumption about what the default may be. */
 #ifndef DEFAULT_TXN_ISOLATION
@@ -279,7 +277,7 @@ typedef struct pk_column
 
 typedef struct cursor
 {
-  const char  *name;
+  char        *name;
   uint	       pk_count;
   my_bool      pk_validated;
   MY_PK_COLUMN pkcol[MY_MAX_PK_PARTS];
@@ -340,7 +338,7 @@ typedef struct tagSTMT
   MYCURSOR	cursor;
   MYERROR	error;
   STMT_OPTIONS	stmt_options;
-  const char	*table_name;
+  char		*table_name;
   char		*query,*query_end;
   /*
     We save a copy of the original query before we modify it for 'WHERE
