@@ -48,18 +48,14 @@
 #define digit(A) ((int) (A - '0'))
 #define option_flag(A,B) ((A)->dbc->flag & B)
 
-#ifdef MYODBC_DBG
-
 #define MYLOG_QUERY(A,B) if ((A)->dbc->flag & FLAG_LOG_QUERY) \
 			   query_print((A)->dbc->query_log,(char*) B)
 
 #define MYLOG_DBC_QUERY(A,B) if((A)->flag & FLAG_LOG_QUERY) \
 			   query_print((A)->query_log,(char*) B)
 
-#else
-#define MYLOG_QUERY(A,B)
-#define MYLOG_DBC_QUERY(A,B)
-#endif
+
+#define UTF8_CHARSET_NUMBER 33
 
 /* Wrappers to hide differences in client library versions. */
 #if MYSQL_VERSION_ID >= 40100
@@ -70,6 +66,43 @@
     int2str((val), (dst), (radix))
 #endif
 
+#if MYSQL_VERSION_ID >= 50100
+typedef unsigned char * DYNAMIC_ELEMENT;
+#else
+typedef char * DYNAMIC_ELEMENT;
+#endif
+
+#if MYSQL_VERSION_ID >= 50100
+# define MYODBC_FIELD_STRING(name, len, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, (len), 0, 0, 0, 0, 0, 0, \
+    0, 0, (flags), 0, UTF8_CHARSET_NUMBER, MYSQL_TYPE_VAR_STRING, NULL}
+# define MYODBC_FIELD_SHORT(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, 5, 5, 0, 0, 0, 0, 0, 0, \
+    0, (flags), 0, 0, MYSQL_TYPE_SHORT, NULL}
+# define MYODBC_FIELD_LONG(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, 11, 11, 0, 0, 0, 0, 0, 0, \
+    0, (flags), 0, 0, MYSQL_TYPE_LONG, NULL}
+#elif MYSQL_VERSION_ID >= 40100
+/* we use 3 here as SYSTEM_CHARSET_MBMAXLEN is not defined in v5.0 mysql_com.h */
+# define MYODBC_FIELD_STRING(name, len, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, (len) * 3, 0, 0, 0, 0, 0, 0, \
+    0, 0, (flags), 0, UTF8_CHARSET_NUMBER, MYSQL_TYPE_VAR_STRING}
+# define MYODBC_FIELD_SHORT(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, 5, 5, 0, 0, 0, 0, 0, 0, \
+    0, (flags), 0, 0, MYSQL_TYPE_SHORT}
+# define MYODBC_FIELD_LONG(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, NullS, NullS, 11, 11, 0, 0, 0, 0, 0, 0, \
+    0, (flags), 0, 0, MYSQL_TYPE_LONG}
+#else
+# define MYODBC_FIELD_STRING(name, len, flags) \
+  {(name), NullS, NullS, NullS, NullS, (len), 0, (flags), 0, \
+    MYSQL_TYPE_VAR_STRING}
+# define MYODBC_FIELD_SHORT(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, 5, 5, (flags), 0, MYSQL_TYPE_SHORT}
+# define MYODBC_FIELD_LONG(name, flags) \
+  {(name), NullS, NullS, NullS, NullS, 11, 11, (flags), 0, MYSQL_TYPE_LONG}
+#endif
+
 /*
   Utility function prototypes that share among files
 */
@@ -112,7 +145,7 @@ void set_mem_error(MYSQL *mysql);
 void translate_error(char *save_state,myodbc_errid errid,uint mysql_err);
 
 SQLSMALLINT get_sql_data_type(STMT *stmt, MYSQL_FIELD *field, char *buff);
-SQLLEN get_column_size(STMT *stmt, MYSQL_FIELD *field, my_bool actual);
+SQLULEN get_column_size(STMT *stmt, MYSQL_FIELD *field, my_bool actual);
 SQLLEN get_decimal_digits(STMT *stmt, MYSQL_FIELD *field);
 SQLLEN get_transfer_octet_length(STMT *stmt, MYSQL_FIELD *field);
 SQLLEN get_display_size(STMT *stmt, MYSQL_FIELD *field);
@@ -183,15 +216,13 @@ int myodbc_strcasecmp(const char *s, const char *t);
 int myodbc_casecmp(const char *s, const char *t, uint len);
 my_bool reget_current_catalog(DBC FAR *dbc);
 
-ulong myodbc_escape_wildcard(MYSQL *mysql, char *to, ulong to_length,
-                             const char *from, ulong length);
+ulong myodbc_escape_string(MYSQL *mysql, char *to, ulong to_length,
+                           const char *from, ulong length, int escape_id);
 
 /* Functions used when debugging */
-#ifdef MYODBC_DBG
 void query_print(FILE *log_file,char *query);
 FILE *init_query_log(void);
 void end_query_log(FILE *query_log);
-#endif
 
 #ifdef __WIN__
 #define cmp_database(A,B) myodbc_strcasecmp((const char *)(A),(const char *)(B))
