@@ -172,8 +172,8 @@ SQLRETURN my_SQLPrepare( SQLHSTMT hstmt, SQLCHAR FAR *szSqlStr, SQLINTEGER cbSql
                 if (param_count >= stmt->params.elements)
                 {
                     PARAM_BIND tmp_param;
-                    bzero((gptr) &tmp_param,sizeof(tmp_param));
-                    if (push_dynamic(&stmt->params,(gptr) &tmp_param))
+                    bzero(&tmp_param,sizeof(tmp_param));
+                    if (push_dynamic(&stmt->params,(DYNAMIC_ELEMENT)&tmp_param))
                     {
                         return set_error(stmt, MYERR_S1001, NULL, 4001);
                     }
@@ -239,10 +239,10 @@ SQLRETURN SQL_API my_SQLBindParameter( SQLHSTMT     hstmt,
             old->alloced= 0;
             my_free(old->value,MYF(0));
         }
-        memcpy((gptr) &param,(gptr) old,sizeof(param));
+        memcpy(&param, old, sizeof(param));
     }
     else
-        bzero((gptr)&param, sizeof(param));
+        bzero(&param, sizeof(param));
     /* Simply record the values. These are used later (SQLExecute) */
     param.used= 1;
     param.SqlType= fSqlType;
@@ -252,7 +252,7 @@ SQLRETURN SQL_API my_SQLBindParameter( SQLHSTMT     hstmt,
     param.actual_len= pcbValue;
     param.real_param_done= TRUE;
 
-    if (set_dynamic(&stmt->params,(gptr) &param,ipar))
+    if (set_dynamic(&stmt->params, (DYNAMIC_ELEMENT)&param, ipar))
     {
         set_error(stmt,MYERR_S1001,NULL,4001);
         return SQL_ERROR;
@@ -261,6 +261,37 @@ SQLRETURN SQL_API my_SQLBindParameter( SQLHSTMT     hstmt,
 }
 
 
+/**
+  Deprecated function, for more details see SQLBindParamater. 
+
+  @param[in] stmt           Handle to statement
+  @param[in] ipar           Parameter number
+  @param[in] fCType         Value type
+  @param[in] fSqlType       Parameter type
+  @param[in] cbColDef       Column size
+  @param[in] ibScale        Decimal digits
+  @param[in] rgbValue       Parameter value pointer
+  @param[in] pcbValue       String length or index pointer
+
+  @return SQL_SUCCESS or SQL_ERROR (and diag is set)
+
+*/
+
+SQLRETURN SQL_API SQLSetParam(SQLHSTMT        hstmt,
+                              SQLUSMALLINT    ipar, 
+                              SQLSMALLINT     fCType, 
+                              SQLSMALLINT     fSqlType,
+                              SQLULEN         cbColDef, 
+                              SQLSMALLINT     ibScale,
+                              SQLPOINTER      rgbValue, 
+                              SQLLEN *        pcbValue)
+{
+  return my_SQLBindParameter(hstmt, ipar, SQL_PARAM_INPUT_OUTPUT, fCType, 
+                             fSqlType, cbColDef, ibScale, rgbValue, 
+                             SQL_SETPARAM_VALUE_MAX, pcbValue);
+}
+
+
 /*
   @type    : ODBC 2.0 API
   @purpose : binds a buffer to a parameter marker in an SQL statement.
