@@ -209,7 +209,7 @@ sql_get_data(STMT *stmt, SQLSMALLINT fCType, MYSQL_FIELD *field,
 
     case SQL_C_ULONG:
       if (rgbValue)
-        *((SQLUINTEGER *)rgbValue)= (SQLUINTEGER)atol(value);
+        *((SQLUINTEGER *)rgbValue)= (SQLUINTEGER)strtoul(value, NULL, 10);
       *pcbValue= sizeof(SQLUINTEGER);
       break;
 
@@ -341,6 +341,11 @@ sql_get_data(STMT *stmt, SQLSMALLINT fCType, MYSQL_FIELD *field,
           *((ulonglong *)rgbValue)= (ulonglong)strtoull(value, NULL, 10);
       *pcbValue= sizeof(ulonglong);
       break;
+
+    default:
+      return set_error(stmt,MYERR_07006,
+                       "Restricted data type attribute violation",0);
+      break;
     }
   }
 
@@ -408,7 +413,7 @@ BOOL isStatementForRead( STMT FAR *stmt )
   @type    : myodbc3 internal
   @purpose : execute the query if it is only prepared. This is needed
   because the ODBC standard allows calling some functions
-  before SQLExecute(). (Stupid!)
+  before SQLExecute().
 */
 
 static SQLRETURN check_result(STMT FAR *stmt )
@@ -461,7 +466,7 @@ SQLRETURN do_dummy_parambind(SQLHSTMT hstmt)
             param->buffer= "NULL";
             param->actual_len= 0;
 
-            if ( set_dynamic(&stmt->params,(gptr)param,nparam) )
+            if (set_dynamic(&stmt->params, (DYNAMIC_ELEMENT)param, nparam))
                 return set_stmt_error(stmt,"S1001","Not enough memory",4001);
         }
     }
@@ -529,13 +534,20 @@ SQLRETURN SQL_API SQLDescribeCol( SQLHSTMT          hstmt,
       *pfSqlType= get_sql_data_type(stmt, field, NULL);
     if (pnColumnSize)
       *pnColumnSize= get_column_size(stmt, field, FALSE);
+
     if (pibScale)
-      *pibScale= max(0, get_decimal_digits(stmt, field));
-    if ( pfNullable )
-        *pfNullable= (((field->flags & (NOT_NULL_FLAG)) ==
-                       NOT_NULL_FLAG) ?
-                      SQL_NO_NULLS :
-                      SQL_NULLABLE);
+      *pibScale= (SQLSMALLINT)myodbc_max(0, get_decimal_digits(stmt, field));
+    if (pfNullable)
+    {
+      if ((field->flags & NOT_NULL_FLAG) &&
+          !(field->flags & TIMESTAMP_FLAG) &&
+          !(field->flags & AUTO_INCREMENT_FLAG))
+      {
+        *pfNullable= SQL_NO_NULLS;
+      }
+      else
+        *pfNullable= SQL_NULLABLE;
+    }
 
     if ( stmt->dbc->flag & FLAG_FULL_COLUMN_NAMES && field->table )
     {
@@ -549,7 +561,7 @@ SQLRETURN SQL_API SQLDescribeCol( SQLHSTMT          hstmt,
         strxmov(tmp,field->table,".",field->name,NullS);
         error= copy_str_data(SQL_HANDLE_STMT, stmt, szColName,
                              cbColNameMax, pcbColName, tmp);
-        my_free((gptr) tmp,MYF(0));
+        my_free(tmp, MYF(0));
         return error;
     }
     return copy_str_data(SQL_HANDLE_STMT, stmt, szColName, cbColNameMax,
@@ -558,7 +570,7 @@ SQLRETURN SQL_API SQLDescribeCol( SQLHSTMT          hstmt,
 
 /*
   @type    : myodbc3 internal
-  @purpose : rerunrs column atribute values
+  @purpose : returns column attribute values
 */
 
 SQLRETURN SQL_API
@@ -582,10 +594,10 @@ get_col_attr(SQLHSTMT     StatementHandle,
 
     if ( !stmt->result )
         return set_stmt_error(stmt,"07005","No result set",0);
-#ifdef CHECK_EXTRA_ARGUMENTS
+
     if ( ColumnNumber > stmt->result->field_count )
         return set_error(StatementHandle, MYERR_07009,NULL,0);
-#endif
+
     if ( !StringLengthPtr )
         StringLengthPtr= &str_length;
 
@@ -670,15 +682,21 @@ get_col_attr(SQLHSTMT     StatementHandle,
             break;
 
         case SQL_DESC_FIXED_PREC_SCALE:
-            if (field->type == MYSQL_TYPE_DECIMAL ||
-                field->type == MYSQL_TYPE_NEWDECIMAL)
-              *(SQLINTEGER *)NumericAttributePtr= SQL_TRUE;
-            else
-              *(SQLINTEGER *)NumericAttributePtr= SQL_FALSE;
+            /* We don't support any fixed-precision type, such as MONEY */
+            *(SQLINTEGER *)NumericAttributePtr= SQL_FALSE;
             break;
 
         case SQL_DESC_LENGTH:
-          *NumericAttributePtr= get_column_size(stmt, field, TRUE);
+          {
+            /* 
+                Always return signed length value to keep the compatibility with
+                unixODBC and iODBC
+            */
+            SQLULEN col_len;
+            col_len= get_column_size(stmt, field, TRUE);
+            *NumericAttributePtr= (sizeof(SQLLEN) == 4) && 
+                                    (col_len > INT_MAX32) ? INT_MAX32 : col_len;
+          }
           break;
 
         case SQL_COLUMN_LENGTH:
@@ -695,14 +713,8 @@ get_col_attr(SQLHSTMT     StatementHandle,
             case MYSQL_TYPE_TINY_BLOB:
             case MYSQL_TYPE_MEDIUM_BLOB:
             case MYSQL_TYPE_BLOB:
-            case MYSQL_TYPE_DATE:
-            case MYSQL_TYPE_DATETIME:
-            case MYSQL_TYPE_NEWDATE:
             case MYSQL_TYPE_VAR_STRING:
             case MYSQL_TYPE_STRING:
-            case MYSQL_TYPE_TIMESTAMP:
-            case MYSQL_TYPE_TIME:
-            case MYSQL_TYPE_YEAR:
               if (field->charsetnr == 63)
               {
                 if (FieldIdentifier == SQL_DESC_LITERAL_PREFIX)
@@ -714,10 +726,16 @@ get_col_attr(SQLHSTMT     StatementHandle,
                                        CharacterAttributePtr,
                                        BufferLength, StringLengthPtr, "");
               }
-              else
-                return copy_str_data(SQL_HANDLE_STMT, stmt,
-                                     CharacterAttributePtr,
-                                     BufferLength, StringLengthPtr, "'");
+              /* FALLTHROUGH */
+
+            case MYSQL_TYPE_DATE:
+            case MYSQL_TYPE_DATETIME:
+            case MYSQL_TYPE_NEWDATE:
+            case MYSQL_TYPE_TIMESTAMP:
+            case MYSQL_TYPE_TIME:
+            case MYSQL_TYPE_YEAR:
+              return copy_str_data(SQL_HANDLE_STMT, stmt, CharacterAttributePtr,
+                                   BufferLength, StringLengthPtr, "'");
 
             default:
                 return copy_str_data(SQL_HANDLE_STMT, stmt,
@@ -760,14 +778,22 @@ get_col_attr(SQLHSTMT     StatementHandle,
 
         case SQL_COLUMN_PRECISION:
         case SQL_DESC_PRECISION:
-          *(SQLINTEGER *)NumericAttributePtr= get_column_size(stmt, field,
-                                                              FALSE);
+          {
+            /* 
+                Always return signed length value to keep the compatibility with
+                unixODBC and iODBC
+            */
+            SQLULEN col_len= get_column_size(stmt, field, FALSE);
+            *(SQLLEN *)NumericAttributePtr= (sizeof(SQLLEN) == 4) && 
+                                    (col_len > INT_MAX32) ? INT_MAX32 : col_len;
+          }
           break;
 
         case SQL_COLUMN_SCALE:
         case SQL_DESC_SCALE:
-          *(SQLINTEGER *)NumericAttributePtr= max(0, get_decimal_digits(stmt,
-                                                                        field));
+          *(SQLINTEGER *)NumericAttributePtr= myodbc_max(0,
+                                                         get_decimal_digits(stmt,
+                                                                            field));
           break;
 
         case SQL_DESC_SCHEMA_NAME:
@@ -775,8 +801,23 @@ get_col_attr(SQLHSTMT     StatementHandle,
                                  BufferLength,StringLengthPtr, "");
 
         case SQL_DESC_SEARCHABLE:
+          /*
+            We limit BLOB/TEXT types to SQL_PRED_CHAR due an oversight in ADO
+            causing problems with updatable cursors.
+          */
+          switch (field->type)
+          {
+          case MYSQL_TYPE_TINY_BLOB:
+          case MYSQL_TYPE_BLOB:
+          case MYSQL_TYPE_MEDIUM_BLOB:
+          case MYSQL_TYPE_LONG_BLOB:
+            *(SQLINTEGER *)NumericAttributePtr= SQL_PRED_CHAR;
+            break;
+          default:
             *(SQLINTEGER *)NumericAttributePtr= SQL_SEARCHABLE;
             break;
+          }
+          break;
 
         case SQL_DESC_TYPE:
           {
@@ -940,7 +981,7 @@ SQLRETURN SQL_API SQLBindCol( SQLHSTMT      hstmt,
                 stmt->bound_columns= 0;
                 return set_error(stmt,MYERR_S1001,NULL,4001);
             }
-            bzero((gptr) (stmt->bind+stmt->bound_columns),
+            bzero((stmt->bind+stmt->bound_columns),
                   (icol+1-stmt->bound_columns)*sizeof(BIND));
             stmt->bound_columns= icol+1;
         }
@@ -1002,11 +1043,11 @@ my_bool set_dynamic_result(STMT FAR *stmt)
         return 1;
 
     pthread_mutex_lock(&stmt->dbc->lock);
-    x_free((gptr) stmt->odbc_types);
+    x_free(stmt->odbc_types);
     if (!stmt->fake_result)
       mysql_free_result(stmt->result);
     else
-      x_free((gptr)stmt->result);
+      x_free(stmt->result);
     stmt->result= 0;
     stmt->fake_result= 0;
     stmt->odbc_types= 0;
@@ -1062,7 +1103,7 @@ SQLRETURN SQL_API SQLGetData( SQLHSTMT      hstmt,
     }
 
     if ( !(stmt->dbc->flag & FLAG_NO_LOCALE) )
-        setlocale(LC_NUMERIC,"English");
+      setlocale(LC_NUMERIC, "C");
     result= sql_get_data( stmt,
                           (SQLSMALLINT) (fCType == SQL_C_DEFAULT ? stmt->odbc_types[icol] : fCType),
                           stmt->result->fields+icol,
@@ -1230,14 +1271,6 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
         if ( fFetchType != SQL_FETCH_NEXT && !(stmt->dbc->flag & FLAG_SAFE) )
             return  set_error(stmt,MYERR_S1106,
                               "Wrong fetchtype with FORWARD ONLY cursor", 0);
-
-        if ((stmt->dbc->flag & FLAG_NO_CACHE))
-        {
-          if (stmt->result_array)
-            values= stmt->result_array + (cur_row * stmt->result->field_count);
-          else
-            values= mysql_fetch_row(stmt->result);
-        }
     }
 
     if ( if_dynamic_cursor(stmt) && set_dynamic_result(stmt) )
@@ -1311,7 +1344,7 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
     if ( !stmt->result_array && !if_forward_cache(stmt) )
     {
         /*
-          If Dynamic, it looses the stmt->end_of_set, so
+          If Dynamic, it loses the stmt->end_of_set, so
           seek to desired row, might have new data or
           might be deleted
         */
@@ -1324,7 +1357,12 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
     }
     stmt->current_row= cur_row;
 
-    rows_to_fetch= min(max_row-cur_row, (long)stmt->stmt_options.rows_in_set);
+    if (if_forward_cache(stmt) && !stmt->result_array)
+      rows_to_fetch= stmt->stmt_options.rows_in_set;
+    else
+      rows_to_fetch= myodbc_min(max_row-cur_row,
+                                (long)stmt->stmt_options.rows_in_set);
+
     if ( !rows_to_fetch )
     {
         *pcrow= 0;
@@ -1335,7 +1373,7 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
     }
 
     if ( !(stmt->dbc->flag & FLAG_NO_LOCALE) )
-        setlocale(LC_NUMERIC,"English");
+      setlocale(LC_NUMERIC, "C");
     res= SQL_SUCCESS;
     for ( i= 0 ; i < rows_to_fetch ; i++ )
     {
@@ -1347,14 +1385,11 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
         }
         else
         {
-            if ( !if_forward_cache(stmt) )
-            {
-                /* This code will ensure that values is alway set */
-                if ( i == 0 )
-                    save_position= mysql_row_tell(stmt->result);
-                if ( !(values= mysql_fetch_row(stmt->result)) )
-                    break;
-            }
+            /* This code will ensure that values is always set */
+            if ( i == 0 )
+                save_position= mysql_row_tell(stmt->result);
+            if ( !(values= mysql_fetch_row(stmt->result)) )
+                break;
             if ( stmt->fix_fields )
                 values= (*stmt->fix_fields)(stmt,values);
             else
@@ -1381,7 +1416,7 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
                 if ( bind->rgbValue || bind->pcbValue )
                 {
                     SQLLEN offset,pcb_offset;
-                    SQLLEN pcbValue;
+                    SQLLEN pcbValue= 0;
 
                     if ( stmt->stmt_options.bind_type == SQL_BIND_BY_COLUMN )
                     {
@@ -1418,7 +1453,7 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
                         else
                             res= SQL_ERROR;
                     }
-                    if (bind->pcbValue)
+                    if (bind->pcbValue && SQL_SUCCEEDED(tmp_res))
                       *(bind->pcbValue + (pcb_offset / sizeof(SQLLEN))) = pcbValue;
                 }
                 if ( lengths )
@@ -1460,6 +1495,9 @@ SQLRETURN SQL_API my_SQLExtendedFetch( SQLHSTMT             hstmt,
     if ( !(stmt->dbc->flag & FLAG_NO_LOCALE) )
         setlocale(LC_NUMERIC,default_locale);
 
+    if (SQL_SUCCEEDED(res) && stmt->rows_found_in_set == 0)
+      return SQL_NO_DATA_FOUND;
+
     return res;
 }
 
