@@ -114,7 +114,7 @@ void fix_result_types(STMT *stmt)
                 stmt->bound_columns= 0;
                 return;
             }
-            bzero((gptr) (stmt->bind+stmt->bound_columns),
+            bzero((stmt->bind+stmt->bound_columns),
                   (result->field_count -stmt->bound_columns)*sizeof(BIND));
             stmt->bound_columns= result->field_count;
         }
@@ -205,7 +205,7 @@ SQLRETURN copy_str_data(SQLSMALLINT HandleType, SQLHANDLE Handle,
     if ( rgbValue )
         strmake((char*) rgbValue, src, cbValueMax);
 
-    if ( min(*pcbValue , cbValueMax) != *pcbValue )
+    if ( myodbc_min(*pcbValue , cbValueMax) != *pcbValue )
         return SQL_SUCCESS_WITH_INFO;
     return SQL_SUCCESS;
 }
@@ -255,16 +255,34 @@ copy_lresult(SQLSMALLINT HandleType, SQLHANDLE Handle,
              !(((STMT FAR*)Handle)->dbc->flag & FLAG_PAD_SPACE) )
             fill_length= src_length;
     }
-    if ( *offset == (ulong) ~0L )
-        *offset= 0;         /* First call */
-    else if ( arg_length && *offset >= (ulong) fill_length )
-        return SQL_NO_DATA_FOUND;
 
-    src+= *offset;
-    src_length-= (long) *offset;
-    fill_length-= *offset;
+    if (arg_length && *offset == (ulong) ~0L)
+    {
+      /*
+        This is first call. Even if data has zero size, we don't
+        return SQL_NO_DATA_FOUND.
+      */
+      *offset= 0;
+    }
+    else if (*offset != (ulong) ~0L && *offset >= (ulong) fill_length)
+    {
+      /*
+        If not the first call, and we have no data left,
+        must be a call after we gave the last data.
+        We always return SQL_NO_DATA_FOUND in this case,
+        even if size is 0.
+      */
+      return SQL_NO_DATA_FOUND;
+    }
 
-    length= min(fill_length, cbValueMax);
+    if (*offset != (ulong) ~0L)
+    {
+      src+= *offset;
+      src_length-= (long) *offset;
+      fill_length-= *offset;
+    }
+
+    length= myodbc_min(fill_length, cbValueMax);
     (*offset)+= length;        /* Fix for next call */
     if ( pcbValue )
         *pcbValue= fill_length;
@@ -320,7 +338,7 @@ SQLRETURN copy_binary_result( SQLSMALLINT   HandleType,
     src+= *offset;
     src_length-= *offset;
     length= cbValueMax ? (ulong)(cbValueMax-1)/2 : 0;
-    length= min(src_length,length);
+    length= myodbc_min(src_length,length);
     (*offset)+= length;     /* Fix for next call */
     if ( pcbValue )
         *pcbValue= src_length*2;
@@ -353,7 +371,9 @@ SQLRETURN copy_binary_result( SQLSMALLINT   HandleType,
 */
 SQLSMALLINT get_sql_data_type(STMT *stmt, MYSQL_FIELD *field, char *buff)
 {
-  my_bool field_is_binary= test(field->charsetnr == 63);
+  my_bool field_is_binary= test(field->charsetnr == 63) &&
+                           (test(field->org_table_length > 0) ||
+                            ((stmt->dbc->flag & FLAG_NO_BINARY_RESULT) == 0));
 
   switch (field->type) {
   case MYSQL_TYPE_BIT:
@@ -490,19 +510,10 @@ SQLSMALLINT get_sql_data_type(STMT *stmt, MYSQL_FIELD *field, char *buff)
   */
   case MYSQL_TYPE_VARCHAR:
   case MYSQL_TYPE_VAR_STRING:
-#ifdef SERVER_BUG_10491_FIXED
-    /**
-      @todo Re-enable this when Bug #10491 is fixed in the server.
-    */
     if (buff)
       (void)strmov(buff, field_is_binary ? "varbinary" : "varchar");
 
     return field_is_binary ? SQL_VARBINARY : SQL_VARCHAR;
-#else
-    if (buff)
-      (void)strmov(buff, "varchar");
-    return SQL_VARCHAR;
-#endif
 
   case MYSQL_TYPE_TINY_BLOB:
     if (buff)
@@ -550,6 +561,25 @@ SQLSMALLINT get_sql_data_type(STMT *stmt, MYSQL_FIELD *field, char *buff)
 }
 
 
+/**
+  Fill the column size buffer accordingly to size of SQLULEN
+  @param[in,out]  buff
+  @param[in]      stmt
+  @param[in]      field
+  @param[in]      actual  If true, field->max_length is used instead of
+                          field->length, to retrieve the actual length of
+                          data in the field
+
+  @return  void
+*/
+void fill_column_size_buff(char *buff, STMT *stmt, MYSQL_FIELD *field,
+                       my_bool actual)
+{
+	sprintf(buff, (sizeof(SQLULEN) == 4 ? "%ld" : "%llu"), 
+		    get_column_size(stmt, field, actual));
+}
+
+
 /**
   Get the column size (in characters) of a field, as defined at:
     http://msdn2.microsoft.com/en-us/library/ms711786.aspx
@@ -562,12 +592,14 @@ SQLSMALLINT get_sql_data_type(STMT *stmt, MYSQL_FIELD *field, char *buff)
 
   @return  The column size of the field
 */
-SQLLEN get_column_size(STMT *stmt __attribute__((unused)), MYSQL_FIELD *field,
+SQLULEN get_column_size(STMT *stmt, MYSQL_FIELD *field,
                        my_bool actual)
 {
   CHARSET_INFO *charset= get_charset(field->charsetnr, MYF(0));
   unsigned int mbmaxlen= charset ? charset->mbmaxlen : 1;
-  SQLLEN length= actual ? field->max_length : field->length;
+  SQLULEN length= (actual || field->max_length > field->length )
+                  ? field->max_length
+                  : field->length;
 
   switch (field->type) {
   case MYSQL_TYPE_TINY:
@@ -617,11 +649,11 @@ SQLLEN get_column_size(STMT *stmt __attribute__((unused)), MYSQL_FIELD *field,
   case MYSQL_TYPE_BIT:
     /*
       We treat a BIT(n) as a SQL_BIT if n == 1, otherwise we treat it
-      as a SQL_BINARY, so length is (bits + 7) / 8. * 2
+      as a SQL_BINARY, so length is (bits + 7) / 8.
     */
     if (length == 1)
       return 1;
-    return (length + 7) / 8 * 2;
+    return (length + 7) / 8;
 
   case MYSQL_TYPE_ENUM:
   case MYSQL_TYPE_SET:
@@ -633,10 +665,11 @@ SQLLEN get_column_size(STMT *stmt __attribute__((unused)), MYSQL_FIELD *field,
   case MYSQL_TYPE_LONG_BLOB:
   case MYSQL_TYPE_BLOB:
   case MYSQL_TYPE_GEOMETRY:
-    if (field->charsetnr == 63)
-      return length * 2;
-    else
-      return length / mbmaxlen;
+    if (field->charsetnr != 63)
+      length= length / mbmaxlen;
+
+    return (stmt->dbc->flag & FLAG_COLUMN_SIZE_S32) ?
+            (length > INT_MAX32 ? INT_MAX32 : length) : length;
   }
 
   return SQL_NO_TOTAL;
@@ -1014,7 +1047,7 @@ my_bool str_to_ts(SQL_TIMESTAMP_STRUCT *ts, const char *str, int zeroToMin)
 
     if ( length == 6 || length == 12 )  /* YYMMDD or YYMMDDHHMMSS */
     {
-        bmove_upp(to+2,to,length);
+        memmove(to+2, to, length);
         if ( buff[0] <= '6' )
         {
             buff[0]='2';
@@ -1256,7 +1289,7 @@ my_bool dynstr_append_quoted_name(DYNAMIC_STRING *str, const char *name)
 
 my_bool reget_current_catalog(DBC FAR *dbc)
 {
-    my_free((gptr) dbc->database,MYF(0));
+    my_free(dbc->database,MYF(0));
     if ( odbc_stmt(dbc, "select database()") )
     {
         return 1;
@@ -1356,7 +1389,6 @@ int myodbc_casecmp(const char *s, const char *t, uint len)
   @purpose : logs the queries sent to server
 */
 
-#ifdef MYODBC_DBG
 void query_print(FILE *log_file,char *query)
 {
     if ( log_file && query )
@@ -1404,12 +1436,6 @@ void end_query_log(FILE *query_log)
     }
 }
 
-#else
-void query_print(char *query __attribute__((unused)))
-{
-}
-#endif /* !MYODBC_DBG */
-
 
 my_bool is_minimum_version(const char *server_version,const char *version,
                            uint length)
@@ -1423,17 +1449,19 @@ my_bool is_minimum_version(const char *server_version,const char *version,
 /**
  Escapes a string that may contain wildcard characters (%, _) and other
  problematic characters (", ', \n, etc). Like mysql_real_escape_string() but
- also including % and _.
+ also including % and _. Can be used with an identified by passing escape_id.
 
  @param[in]   mysql         Pointer to MYSQL structure
  @param[out]  to            Buffer for escaped string
  @param[in]   to_length     Length of destination buffer, or 0 for "big enough"
  @param[in]   from          The string to escape
  @param[in]   length        The length of the string to escape
+ @param[in]   escape_id     Escaping an identified that will be quoted
 
 */
-ulong myodbc_escape_wildcard(MYSQL *mysql, char *to, ulong to_length,
-                             const char *from, ulong length)
+ulong myodbc_escape_string(MYSQL *mysql __attribute__((unused)),
+                           char *to, ulong to_length,
+                           const char *from, ulong length, int escape_id)
 {
   const char *to_start= to;
   const char *end, *to_end=to_start + (to_length ? to_length-1 : 2*length);
@@ -1455,7 +1483,7 @@ ulong myodbc_escape_wildcard(MYSQL *mysql, char *to, ulong to_length,
         break;
       }
       while (tmp_length--)
-	*to++= *from++;
+        *to++= *from++;
       from--;
       continue;
     }
@@ -1475,34 +1503,34 @@ ulong myodbc_escape_wildcard(MYSQL *mysql, char *to, ulong to_length,
     else
 #endif
     switch (*from) {
-    case 0:				/* Must be escaped for 'mysql' */
+    case 0:         /* Must be escaped for 'mysql' */
       escape= '0';
       break;
-    case '\n':				/* Must be escaped for logs */
+    case '\n':      /* Must be escaped for logs */
       escape= 'n';
       break;
     case '\r':
       escape= 'r';
       break;
     case '\\':
-      escape= '\\';
-      break;
     case '\'':
-      escape= '\'';
-      break;
-    case '"':				/* Better safe than sorry */
-      escape= '"';
-      break;
+    case '"':       /* Better safe than sorry */
     case '_':
-      escape= '_';
-      break;
     case '%':
-      escape= '%';
+      escape= *from;
       break;
-    case '\032':			/* This gives problems on Win32 */
+    case '\032':    /* This gives problems on Win32 */
       escape= 'Z';
       break;
     }
+    /* if escaping an id, only handle back-tick */
+    if (escape_id)
+    {
+      if (*from == '`')
+        escape= *from;
+      else
+        escape= 0;
+    }
     if (escape)
     {
       if (to + 2 > to_end)
