@@ -152,12 +152,6 @@ void MYODBCSetupDataSourceDialog::slotOk()
                 QMessageBox::warning( this, "MyODBC", tr("Missing Data Source Name"), tr("&Ok"), QString::null, QString::null, 0, 1 );
                 return;
             }
-            if ( ptab1->getUser().isEmpty() )
-            {
-                ptab1->plineeditUser->setFocus();
-                QMessageBox::warning( this, "MyODBC", tr("Missing User ID"), tr("&Ok"), QString::null, QString::null, 0, 1 );
-                return;
-            }
 
             /*!
                 ODBC RULE
@@ -192,22 +186,6 @@ void MYODBCSetupDataSourceDialog::slotOk()
             break;
 
         case MYODBCUTIL_DATASOURCE_MODE_DRIVER_CONNECT:
-            /*
-                MYODBC RULE
-
-                A UID is really the only thing we MUST have for a driver connect.
-            */                
-            if ( ptab1->getUser().isEmpty() )
-            {
-#if QT_VERSION >= 0x040000
-                ptabwidget->setCurrentWidget( 0 );
-#else
-                ptabwidget->setCurrentPage( 0 );
-#endif
-                ptab1->plineeditUser->setFocus();
-                QMessageBox::warning( this, "MyODBC", tr("Missing User ID"), tr("&Ok"), QString::null, QString::null, 0, 1 );
-                return;
-            }
             break;
 
         default:
@@ -251,6 +229,8 @@ void MYODBCSetupDataSourceDialog::slotOk()
             pDataSource->pszSSLCAPATH = _global_strdup( ptab2->getSSLCAPath().toAscii() );
         if ( !ptab2->getSSLCipher().isEmpty() )
             pDataSource->pszSSLCIPHER = _global_strdup( ptab2->getSSLCipher().toAscii() );
+        if ( !ptab2->getSSLVerify().isEmpty() )
+            pDataSource->pszSSLVERIFY = _global_strdup( ptab2->getSSLVerify().toAscii() );
 
 #else
         if ( !ptab1->getDataSourceName().isEmpty() )
@@ -284,6 +264,8 @@ void MYODBCSetupDataSourceDialog::slotOk()
             pDataSource->pszSSLCAPATH = _global_strdup( ptab2->getSSLCAPath().ascii() );
         if ( !ptab2->getSSLCipher().isEmpty() )
             pDataSource->pszSSLCIPHER = _global_strdup( ptab2->getSSLCipher().ascii() );
+        if ( !ptab2->getSSLVerify().isEmpty() )
+            pDataSource->pszSSLVERIFY = _global_strdup( ptab2->getSSLVerify().ascii() );
 #endif
 
         unsigned int nFlags = ptab3->getFlags();
@@ -419,14 +401,13 @@ void MYODBCSetupDataSourceDialog::doInit()
     ptab2->setSSLCA( pDataSource->pszSSLCA );
     ptab2->setSSLCAPath( pDataSource->pszSSLCAPATH );
     ptab2->setSSLCipher( pDataSource->pszSSLCIPHER );
+    ptab2->setSSLVerify( pDataSource->pszSSLVERIFY );
     ptab1->setUser( pDataSource->pszUSER );
 
     if ( pDataSource->pszOPTION )
     {
         ulong nOptions = atol( pDataSource->pszOPTION );
-        ptab3->ptab3a->pcheckboxDontOptimizeColumnWidth->setChecked( nOptions & (1 << 0) ? TRUE : FALSE );
         ptab3->ptab3a->pcheckboxReturnMatchingRows->setChecked( nOptions & (1 << 1) ? TRUE : FALSE );
-        ptab3->ptab3d->pcheckboxTraceDriverCalls->setChecked( nOptions & (1 << 2) ? TRUE : FALSE );
         ptab3->ptab3a->pcheckboxAllowBigResults->setChecked( nOptions & (1 << 3) ? TRUE : FALSE );
         ptab3->ptab3b->pcheckboxDontPromptOnConnect->setChecked( nOptions & (1 << 4) ? TRUE : FALSE );
         ptab3->ptab3b->pcheckboxEnableDynamicCursor->setChecked( nOptions & (1 << 5) ? TRUE : FALSE );
@@ -449,6 +430,8 @@ void MYODBCSetupDataSourceDialog::doInit()
         ptab3->ptab3a->pcheckboxEnableReconnect->setChecked( nOptions & (1 << 22) ? TRUE : FALSE );
         ptab3->ptab3a->pcheckboxAutoIncrementIsNull->setChecked( nOptions & (1 << 23) ? TRUE : FALSE );
         ptab3->ptab3c->pcheckboxMultiStatements->setChecked( nOptions & (1 << 26) ? TRUE : FALSE );
+        ptab3->ptab3c->pcheckboxCapColumnSize->setChecked( nOptions & (1 << 27) ? TRUE : FALSE );
+        ptab3->ptab3a->pcheckboxDisableBinaryResult->setChecked( nOptions & (1 << 28) ? TRUE : FALSE );
     }
 
     connect( ppushbuttonTest, SIGNAL(clicked()), SLOT(slotTest()) );
@@ -477,7 +460,7 @@ void MYODBCSetupDataSourceDialog::doInit()
     connect( ptab2->plineeditSSLCA, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab2->plineeditSSLCAPath, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab2->plineeditSSLCipher, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
-	connect( ptab3->ptab3a->pcheckboxDontOptimizeColumnWidth, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
+    connect( ptab2->pcheckboxSSLVerify, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3a->pcheckboxReturnMatchingRows, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3a->pcheckboxAllowBigResults, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3a->pcheckboxUseCompressedProtocol, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
@@ -485,6 +468,7 @@ void MYODBCSetupDataSourceDialog::doInit()
     connect( ptab3->ptab3a->pcheckboxSafe, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3a->pcheckboxEnableReconnect, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3a->pcheckboxAutoIncrementIsNull, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
+    connect( ptab3->ptab3a->pcheckboxDisableBinaryResult, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3b->pcheckboxDontPromptOnConnect, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3b->pcheckboxEnableDynamicCursor, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3b->pcheckboxIgnorePoundInTable, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
@@ -500,7 +484,7 @@ void MYODBCSetupDataSourceDialog::doInit()
     connect( ptab3->ptab3c->pcheckboxDisableTransactions, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3c->pcheckboxForceUseOfForwardOnlyCursors, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3c->pcheckboxMultiStatements, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
-    connect( ptab3->ptab3d->pcheckboxTraceDriverCalls, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
+    connect( ptab3->ptab3c->pcheckboxCapColumnSize, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
     connect( ptab3->ptab3d->pcheckboxSaveQueries, SIGNAL(signalAssistText(const QString&)), ptextbrowserAssist, SLOT(setHtml(const QString&)) );
 
     doApplyMode();
@@ -707,13 +691,15 @@ QString MYODBCSetupDataSourceDialog::buildConnectString()
   if (!ptab2->getSSLKey().isEmpty())
 	  stringConnectIn+= ";SSLKEY=" + ptab2->getSSLKey();
   if (!ptab2->getSSLCert().isEmpty())
-	  stringConnectIn+= ";SSLERT=" + ptab2->getSSLCert();
+	  stringConnectIn+= ";SSLCERT=" + ptab2->getSSLCert();
   if (!ptab2->getSSLCA().isEmpty())
 	  stringConnectIn+= ";SSLCA=" + ptab2->getSSLCA();
   if (!ptab2->getSSLCAPath().isEmpty())
 	  stringConnectIn+= ";SSLCAPATH=" + ptab2->getSSLCAPath();
   if (!ptab2->getSSLCipher().isEmpty())
 	  stringConnectIn+= ";SSLCIPHER=" + ptab2->getSSLCipher();
+  if (!ptab2->getSSLVerify().isEmpty())
+    stringConnectIn+= ";SSLVERIFY=" + ptab2->getSSLVerify();
 
   return stringConnectIn;
 }
@@ -808,7 +794,7 @@ BOOL MYODBCSetupDataSourceDialog::doLoadCharsetNamesUsingDriverManager()
     SQLLEN      nCatalog;
     QString     stringConnectIn= buildConnectString();
 
-    stringlistDatabases += " ";
+    stringlistDatabases += "";
 
     if ( hDBC == SQL_NULL_HDBC )
     {
@@ -904,7 +890,7 @@ BOOL MYODBCSetupDataSourceDialog::doLoadDatabaseNamesUsingDriverManager()
     SQLLEN      nCatalog;
     QString     stringConnectIn= buildConnectString();
 
-    stringlistDatabases += " ";
+    stringlistDatabases += "";
 
     if ( hDBC == SQL_NULL_HDBC )
     {
@@ -1091,3 +1077,5 @@ void MYODBCSetupDataSourceDialog::slotLoadCharsetNames()
 
 
 
+
+
