@@ -50,12 +50,8 @@ unsigned int MYODBCSetupDataSourceTab3::getFlags()
 {
     unsigned int nFlags = 0;
 
-    if ( ptab3a->pcheckboxDontOptimizeColumnWidth->isChecked() )
-        nFlags |= 1 << 0;
     if ( ptab3a->pcheckboxReturnMatchingRows->isChecked() )
         nFlags |= 1 << 1;
-    if ( ptab3d->pcheckboxTraceDriverCalls->isChecked() )
-        nFlags |= 1 << 2;
     if ( ptab3a->pcheckboxAllowBigResults->isChecked() )
         nFlags |= 1 << 3;
     if ( ptab3b->pcheckboxDontPromptOnConnect->isChecked() )
@@ -100,6 +96,10 @@ unsigned int MYODBCSetupDataSourceTab3::getFlags()
         nFlags |= 1 << 23;
     if ( ptab3c->pcheckboxMultiStatements->isChecked() )
         nFlags |= 1 << 26;
+    if ( ptab3c->pcheckboxCapColumnSize->isChecked() )
+        nFlags |= 1 << 27;
+    if ( ptab3a->pcheckboxDisableBinaryResult->isChecked() )
+        nFlags |= 1 << 28;
 
     return nFlags;
 }
