@@ -222,6 +222,15 @@ DECLARE_TEST(t_bug19823)
 
   ok_env(henv, SQLAllocConnect(henv, &hdbc1));
 
+  /*
+   This first connect/disconnect is just to work around a bug in iODBC's
+   implementation of SQLSetConnectAttr. It is fixed in 3.52.6, but
+   Debian/Ubuntu still ships 3.52.5 as of 2007-12-06.
+  */
+  ok_con(hdbc1, SQLConnect(hdbc1, mydsn, SQL_NTS, myuid, SQL_NTS,
+                           mypwd, SQL_NTS));
+  ok_con(hdbc1, SQLDisconnect(hdbc1));
+
   ok_con(hdbc1, SQLSetConnectAttr(hdbc1, SQL_ATTR_LOGIN_TIMEOUT,
                                   (SQLPOINTER)17, 0));
   ok_con(hdbc1, SQLSetConnectAttr(hdbc1, SQL_ATTR_CONNECTION_TIMEOUT,
@@ -275,6 +284,12 @@ DECLARE_TEST(charset_utf8)
     strcat((char *)conn, ";SOCKET=");
     strcat((char *)conn, (char *)mysock);
   }
+  if (myport)
+  {
+    char pbuff[20];
+    sprintf(pbuff, ";PORT=%d", myport);
+    strcat((char *)conn, pbuff);
+  }
 
   ok_env(henv, SQLAllocHandle(SQL_HANDLE_DBC, henv, &hdbc1));
 
@@ -303,7 +318,7 @@ DECLARE_TEST(charset_utf8)
   is_num(my_fetch_int(hstmt1, 16), 30);
 
   ok_stmt(hstmt1, SQLFetch(hstmt1));
-  is_num(my_fetch_int(hstmt1, 7), 20);
+  is_num(my_fetch_int(hstmt1, 7), 10);
   is_num(my_fetch_int(hstmt1, 8), 10);
   is_num(my_fetch_int(hstmt1, 16), 10);
 
@@ -311,6 +326,8 @@ DECLARE_TEST(charset_utf8)
   ok_con(hdbc1, SQLDisconnect(hdbc1));
   ok_con(hdbc1, SQLFreeHandle(SQL_HANDLE_DBC, hdbc1));
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug19345");
+
   return OK;
 }
 
@@ -341,6 +358,12 @@ DECLARE_TEST(charset_gbk)
     strcat((char *)conn, ";SOCKET=");
     strcat((char *)conn, (char *)mysock);
   }
+  if (myport)
+  {
+    char pbuff[20];
+    sprintf(pbuff, ";PORT=%d", myport);
+    strcat((char *)conn, pbuff);
+  }
 
   ok_env(henv, SQLAllocHandle(SQL_HANDLE_DBC, henv, &hdbc1));
 
@@ -414,6 +437,169 @@ DECLARE_TEST(t_bug7445)
 }
 
 
+/**
+ Bug #30774: Username argument to SQLConnect used incorrectly
+*/
+DECLARE_TEST(t_bug30774)
+{
+  SQLHDBC hdbc1;
+  SQLHSTMT hstmt1;
+  SQLCHAR username[80]= {0};
+
+  strcat((char *)username, (char *)myuid);
+  strcat((char *)username, "!!!");
+
+  ok_env(henv, SQLAllocConnect(henv, &hdbc1));
+  ok_con(hdbc1, SQLConnect(hdbc1, mydsn, SQL_NTS,
+                           username, strlen((char *)myuid),
+                           mypwd, SQL_NTS));
+  ok_con(hdbc1, SQLAllocStmt(hdbc1, &hstmt1));
+
+  ok_sql(hstmt1, "SELECT USER()");
+  ok_stmt(hstmt1, SQLFetch(hstmt1));
+  my_fetch_str(hstmt1, username, 1);
+  printMessage("username: %s", username);
+  is(!strstr((char *)username, "!!!"));
+
+  expect_stmt(hstmt1, SQLFetch(hstmt1), SQL_NO_DATA_FOUND);
+
+  ok_stmt(hstmt1, SQLFreeStmt(hstmt1, SQL_DROP));
+
+  ok_con(hdbc1, SQLDisconnect(hdbc1));
+  ok_con(hdbc1, SQLFreeConnect(hdbc1));
+
+  return OK;
+}
+
+
+/**
+  Bug #30840: FLAG_NO_PROMPT doesn't do anything
+*/
+DECLARE_TEST(t_bug30840)
+{
+  HDBC hdbc1;
+  SQLCHAR   conn[256], conn_out[256];
+  SQLSMALLINT conn_out_len;
+
+  if (using_dm(hdbc))
+    skip("test does not work with all driver managers");
+
+  sprintf((char *)conn, "DSN=%s;UID=%s;PASSWORD=%s;OPTION=16",
+          mydsn, myuid, mypwd);
+  if (mysock != NULL)
+  {
+    strcat((char *)conn, ";SOCKET=");
+    strcat((char *)conn, (char *)mysock);
+  }
+  if (myport)
+  {
+    char pbuff[20];
+    sprintf(pbuff, ";PORT=%d", myport);
+    strcat((char *)conn, pbuff);
+  }
+
+  ok_env(henv, SQLAllocHandle(SQL_HANDLE_DBC, henv, &hdbc1));
+
+  ok_con(hdbc1, SQLDriverConnect(hdbc1, (HWND)1, conn, sizeof(conn),
+                                 conn_out, sizeof(conn_out), &conn_out_len,
+                                 SQL_DRIVER_PROMPT));
+
+  ok_con(hdbc1, SQLDisconnect(hdbc1));
+
+  ok_con(hdbc1, SQLFreeHandle(SQL_HANDLE_DBC, hdbc1));
+
+  return OK;
+}
+
+
+/**
+ Bug #32727: Unable to abort distributed transactions enlisted in MSDTC
+*/
+DECLARE_TEST(t_bug32727)
+{
+  is(SQLSetConnectAttr(hdbc, SQL_ATTR_ENLIST_IN_DTC,
+                       (SQLPOINTER)1, SQL_IS_UINTEGER) == SQL_ERROR);
+  return OK;
+}
+
+
+/*
+  Bug #28820: Varchar Field length is reported as larger than actual
+*/
+DECLARE_TEST(t_bug28820)
+{
+  SQLULEN length;
+  SQLSMALLINT i;
+
+  ok_sql(hstmt, "drop table if exists t_bug28820");
+  ok_sql(hstmt, "create table t_bug28820 ("
+                "x varchar(90) character set latin1,"
+                "y varchar(90) character set big5,"
+                "z varchar(90) character set utf8)");
+
+  ok_sql(hstmt, "select x,y,z from t_bug28820");
+
+  for (i= 0; i < 3; ++i)
+  {
+    length= 0;
+    ok_stmt(hstmt, SQLDescribeCol(hstmt, i+1, NULL, 0, NULL,
+                                  NULL, &length, NULL, NULL));
+    is_num(length, 90);
+  }
+
+  ok_sql(hstmt, "drop table if exists t_bug28820");
+  return OK;
+}
+
+
+/*
+  Bug #31959 - Allows dirty reading with SQL_TXN_READ_COMMITTED
+               isolation through ODBC
+*/
+DECLARE_TEST(t_bug31959)
+{
+  SQLCHAR level[50] = "uninitialized";
+  SQLINTEGER i;
+  SQLINTEGER levelid[] = {SQL_TXN_SERIALIZABLE, SQL_TXN_REPEATABLE_READ,
+                          SQL_TXN_READ_COMMITTED, SQL_TXN_READ_UNCOMMITTED};
+  SQLCHAR *levelname[] = {"SERIALIZABLE", "REPEATABLE-READ",
+                          "READ-COMMITTED", "READ-UNCOMMITTED"};
+
+  ok_stmt(hstmt, SQLPrepare(hstmt, "select @@tx_isolation", SQL_NTS));
+
+  /* check all 4 valid isolation levels */
+  for(i = 3; i >= 0; --i)
+  {
+    ok_con(hdbc, SQLSetConnectAttr(hdbc, SQL_ATTR_TXN_ISOLATION,
+                                   (SQLPOINTER)levelid[i], 0));
+    ok_stmt(hstmt, SQLExecute(hstmt));
+    ok_stmt(hstmt, SQLFetch(hstmt));
+    ok_stmt(hstmt, SQLGetData(hstmt, 1, SQL_C_CHAR, level, 50, NULL));
+    is_str(level, levelname[i], strlen(levelname[i]));
+    printMessage("Level = %s\n", level);
+    ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+  }
+
+  /* check invalid value (and corresponding SQL state) */
+  is(SQLSetConnectAttr(hdbc, SQL_ATTR_TXN_ISOLATION, (SQLPOINTER)999, 0) ==
+     SQL_ERROR);
+  {
+  SQLCHAR     sql_state[6];
+  SQLINTEGER  err_code= 0;
+  SQLCHAR     err_msg[SQL_MAX_MESSAGE_LENGTH]= {0};
+  SQLSMALLINT err_len= 0;
+
+  memset(err_msg, 'C', SQL_MAX_MESSAGE_LENGTH);
+  SQLGetDiagRec(SQL_HANDLE_DBC, hdbc, 1, sql_state, &err_code, err_msg,
+                SQL_MAX_MESSAGE_LENGTH - 1, &err_len);
+
+  is_str(sql_state, (SQLCHAR *)"HY024", 5);
+  }
+
+  return OK;
+}
+
+
 BEGIN_TESTS
   ADD_TEST(my_basics)
   ADD_TEST(t_max_select)
@@ -426,6 +612,11 @@ BEGIN_TESTS
   ADD_TEST(charset_utf8)
   ADD_TEST(charset_gbk)
   ADD_TEST(t_bug7445)
+  ADD_TEST(t_bug30774)
+  ADD_TEST(t_bug30840)
+  ADD_TEST(t_bug32727)
+  ADD_TEST(t_bug28820)
+  ADD_TEST(t_bug31959)
 END_TESTS
 
 
