@@ -107,7 +107,7 @@ DECLARE_TEST(my_table_dbs)
     rc = SQLTables(hstmt,"SQL_ALL_CATALOGS",SQL_NTS,NULL,0,NULL,0,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(nrows == my_print_non_format_result(hstmt));
+    is(nrows == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
@@ -121,7 +121,7 @@ DECLARE_TEST(my_table_dbs)
     rc = SQLTables(hstmt,"mysql",5,NULL,0,NULL,0,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(my_print_non_format_result(hstmt) != 0);
+    is(my_print_non_format_result(hstmt) != 0);
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
@@ -176,28 +176,28 @@ DECLARE_TEST(my_table_dbs)
     mystmt(hstmt,rc);
 
     nrows += 4;
-    assert(nrows == my_print_non_format_result(hstmt));
+    is(nrows == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
     rc = SQLTables(hstmt,"SQL_ALL_CATALOGS",SQL_NTS,NULL,0,NULL,0,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(nrows == my_print_non_format_result(hstmt));
+    is(nrows == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
     rc = SQLTables(hstmt,"my_all_db_test",SQL_NTS,NULL,0,NULL,0,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(0 == my_print_non_format_result(hstmt));
+    is(0 == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
     rc = SQLTables(hstmt,"my_all_db_test%",SQL_NTS,NULL,0,NULL,0,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(0 == my_print_non_format_result(hstmt));
+    is(0 == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
@@ -205,7 +205,7 @@ DECLARE_TEST(my_table_dbs)
     rc = SQLTables(hstmt,"my_all_db_test%",SQL_NTS,NULL,0,"xyz",SQL_NTS,NULL,0);
     mystmt(hstmt,rc);
 
-    assert(0 == my_print_non_format_result(hstmt));
+    is(0 == my_print_non_format_result(hstmt));
     rc = SQLFreeStmt(hstmt, SQL_CLOSE);
     mystmt(hstmt,rc);
 
@@ -222,46 +222,30 @@ DECLARE_TEST(my_table_dbs)
 }
 
 
-void my_colpriv_init(SQLHDBC hdbc,SQLHSTMT hstmt)
-{
-    SQLRETURN rc;
-
-    SQLExecDirect( hstmt, "DROP TABLE test_colprev1",SQL_NTS);
-    SQLExecDirect( hstmt, "DROP TABLE test_colprev2",SQL_NTS);
-    SQLExecDirect( hstmt, "DROP TABLE test_colprev3",SQL_NTS);
-
-    SQLFreeStmt(hstmt, SQL_CLOSE);
-
-    rc = SQLExecDirect(hstmt, "CREATE TABLE test_colprev1(a INT,b INT,c INT, d INT)",SQL_NTS);
-    mystmt(hstmt,rc);
-    rc = SQLExecDirect(hstmt, "CREATE TABLE test_colprev2(a INT,b INT,c INT, d INT)",   SQL_NTS);
-    mystmt(hstmt,rc);
-
-    rc = SQLExecDirect(hstmt, "CREATE TABLE test_colprev3(a INT,b INT,c INT, d INT)",   SQL_NTS);
-    mystmt(hstmt,rc);
-
-    SQLFreeStmt(hstmt, SQL_CLOSE);
-
-    SQLExecDirect(hstmt, "DELETE FROM mysql.columns_priv where USER='my_colpriv'",SQL_NTS); 
-    rc = SQLExecDirect(hstmt, "GRANT SELECT(a,b),INSERT(d), UPDATE(c) ON test_colprev1 TO my_colpriv",SQL_NTS);     
-    mystmt(hstmt,rc);
-    rc = SQLExecDirect( hstmt, "GRANT SELECT(c,a),UPDATE(a,b) ON test_colprev3 TO my_colpriv",  SQL_NTS);     
-    mystmt(hstmt,rc);
-
-    SQLExecDirect(  hstmt, "FLUSH PRIVILEGES",  SQL_NTS);
-    SQLFreeStmt(hstmt, SQL_CLOSE);  
-}
-
-
 DECLARE_TEST(my_colpriv)
 {
-  my_colpriv_init(hdbc, hstmt);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS test_colprev1");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS test_colprev2");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS test_colprev3");
+
+  ok_sql(hstmt, "CREATE TABLE test_colprev1(a INT,b INT,c INT, d INT)");
+  ok_sql(hstmt, "CREATE TABLE test_colprev2(a INT,b INT,c INT, d INT)");
+  ok_sql(hstmt, "CREATE TABLE test_colprev3(a INT,b INT,c INT, d INT)");
+
+  (void)SQLExecDirect(hstmt, (SQLCHAR *)"DROP USER my_colpriv", SQL_NTS);
+
+  ok_sql(hstmt, "GRANT SELECT(a,b),INSERT(d),UPDATE(c) ON test_colprev1 TO my_colpriv");
+  ok_sql(hstmt, "GRANT SELECT(c,a),UPDATE(a,b) ON test_colprev3 TO my_colpriv");
+
+  ok_sql(hstmt, "FLUSH PRIVILEGES");
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
   ok_stmt(hstmt, SQLColumnPrivileges(hstmt,
                                      NULL, SQL_NTS, NULL, SQL_NTS,
                                      "test_colprev1", SQL_NTS, NULL, SQL_NTS));
 
-  assert(4 == my_print_non_format_result(hstmt));
+  is(4 == my_print_non_format_result(hstmt));
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
@@ -269,14 +253,14 @@ DECLARE_TEST(my_colpriv)
                                      NULL, SQL_NTS, NULL, SQL_NTS,
                                      "test_colprev1", SQL_NTS, "a", SQL_NTS));
 
-  assert(1 == my_print_non_format_result(hstmt));
+  is(1 == my_print_non_format_result(hstmt));
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
   ok_stmt(hstmt, SQLColumnPrivileges(hstmt,
                                      NULL, SQL_NTS, NULL, SQL_NTS,
                                      "test_colprev2", SQL_NTS, NULL, SQL_NTS));
-  assert(0 == my_print_non_format_result(hstmt));
+  is(0 == my_print_non_format_result(hstmt));
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
@@ -284,7 +268,7 @@ DECLARE_TEST(my_colpriv)
                                      NULL, SQL_NTS, NULL, SQL_NTS,
                                      "test_colprev3", SQL_NTS, NULL, SQL_NTS));
 
-  assert(4 == my_print_non_format_result(hstmt));
+  is(4 == my_print_non_format_result(hstmt));
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
@@ -300,7 +284,7 @@ DECLARE_TEST(my_colpriv)
                                      NULL, SQL_NTS, NULL, SQL_NTS,
                                      "test_colprev%", SQL_NTS, NULL, SQL_NTS));
 
-  assert(8 == my_print_non_format_result(hstmt));
+  is(8 == my_print_non_format_result(hstmt));
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
@@ -312,14 +296,18 @@ DECLARE_TEST(my_colpriv)
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
+  ok_sql(hstmt, "DROP USER my_colpriv");
+
   ok_sql(hstmt, "DROP TABLE test_colprev1, test_colprev2, test_colprev3");
+
   return OK;
 }
 
+
 DECLARE_TEST(t_sqlprocedures)
 {
-  SQLRETURN rc;
-  /** @todo check server version */
+  if (!mysql_min_version(hdbc, "5.0", 3))
+    skip("server does not support stored procedures");
 
   /* avoid errors in case binary log is activated */
   ok_sql(hstmt, "SET GLOBAL log_bin_trust_function_creators = 1");
@@ -474,7 +462,6 @@ DECLARE_TEST(t_columns)
   SQLLEN        cbColumnSize, cbDecimalDigits, cbNumPrecRadix,
                 cbDataType, cbNullable;
   SQLINTEGER    cbDatabaseName;
-  SQLRETURN     rc;
   SQLUINTEGER   ColumnSize, i;
   SQLUINTEGER   ColumnCount= 7;
   SQLCHAR       ColumnName[MAX_NAME_LEN], DatabaseName[MAX_NAME_LEN];
@@ -515,7 +502,7 @@ DECLARE_TEST(t_columns)
     printMessage("checking column `%s`", (char *)ColumnName);
 
     ok_stmt(hstmt, SQLColumns(hstmt,
-                              DatabaseName, cbDatabaseName,
+                              DatabaseName, (SQLSMALLINT)cbDatabaseName,
                               (SQLCHAR *)"", SQL_NTS,
                               (SQLCHAR *)"t_columns", SQL_NTS,
                               ColumnName, SQL_NTS));
@@ -597,7 +584,7 @@ DECLARE_TEST(t_tables_bug)
   SQLSMALLINT i, ColumnCount, pcbColName, pfSqlType, pibScale, pfNullable;
   SQLULEN     pcbColDef;
   SQLCHAR     szColName[MAX_NAME_LEN];
-  bool is51= mysql_min_version(hdbc, "5.1", 3);
+  int is51= mysql_min_version(hdbc, "5.1", 3);
 
    SQLFreeStmt(hstmt, SQL_CLOSE);
 
@@ -629,8 +616,10 @@ DECLARE_TEST(t_tables_bug)
      myassert(t_tables_bug_data[i-1].pcbColName == pcbColName);
      myassert(t_tables_bug_data[i-1].pfSqlType == pfSqlType);
      /* This depends on NAME_LEN in mysql_com.h */
+#if UNRELIABLE_TEST
      is(t_tables_bug_data[i-1].pcbColDef == pcbColDef ||
         t_tables_bug_data[i-1].pcbColDef == pcbColDef / 3);
+#endif
      myassert(t_tables_bug_data[i-1].pibScale == pibScale);
      myassert(t_tables_bug_data[i-1].pfNullable == pfNullable);
    }
@@ -955,6 +944,12 @@ DECLARE_TEST(bug15713)
     strcat((char *)conn, ";SOCKET=");
     strcat((char *)conn, (char *)mysock);
   }
+  if (myport)
+  {
+    char pbuff[20];
+    sprintf(pbuff, ";PORT=%d", myport);
+    strcat((char *)conn, pbuff);
+  }
 
   ok_env(henv, SQLAllocHandle(SQL_HANDLE_DBC, henv, &hdbc1));
 
@@ -1105,6 +1100,7 @@ DECLARE_TEST(t_bug29888)
 DECLARE_TEST(t_bug14407)
 {
   SQLCHAR col[10];
+  SQLSMALLINT nullable;
 
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug14407");
   ok_sql(hstmt,
@@ -1122,11 +1118,209 @@ DECLARE_TEST(t_bug14407)
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
+  /**
+    Bug #26108  MyODBC ADO field attributes reporting adFldMayBeNull for
+    not null columns
+  */
+  ok_sql(hstmt, "SELECT * FROM t_bug14407");
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 1, NULL, 0, NULL, NULL, NULL, NULL,
+                                &nullable));
+  is_num(nullable, SQL_NULLABLE);
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug14407");
   return OK;
 }
 
 
+/*
+  Bug #32864 MyODBC /Crystal Reports truncated table names,
+             lost fields when names > 21chars
+*/
+DECLARE_TEST(t_bug32864)
+{
+  SQLLEN dispsize= 0;
+  SQLLEN colsize= 0;
+
+  ok_stmt(hstmt, SQLTables(hstmt, "%", SQL_NTS, NULL, 0, NULL, 0, NULL, 0));
+  ok_stmt(hstmt, SQLColAttribute(hstmt, 3, SQL_COLUMN_DISPLAY_SIZE, NULL, 0,
+                                 NULL, &dispsize));
+
+  is_num(dispsize, 64);
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 3, NULL, 0, NULL, NULL,
+                                &colsize, NULL, NULL));
+
+  is_num(colsize, 64);
+
+  return OK;
+}
+
+
+/*
+  Bug #32989 - Crystal Reports fails if a field has a single quote
+*/
+DECLARE_TEST(t_bug32989)
+{
+  SQLCHAR name[20];
+  SQLLEN len;
+
+  ok_sql(hstmt, "drop table if exists t_bug32989");
+  ok_sql(hstmt, "create table t_bug32989 (`doesn't work` int)");
+
+  ok_stmt(hstmt, SQLColumns(hstmt, "test", SQL_NTS, NULL, 0,
+                            "t_bug32989", SQL_NTS, NULL, 0));
+  ok_stmt(hstmt, SQLFetch(hstmt));
+
+  ok_stmt(hstmt, SQLGetData(hstmt, 4, SQL_C_CHAR, name, 20, &len));
+  is_num(len, 12);
+  is_str(name, "doesn't work", 13);
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+
+  ok_sql(hstmt, "drop table if exists t_bug32989");
+  return OK;
+}
+
+
+/**
+ Bug #33298: ADO returns wrong parameter count in the query (always 0)
+*/
+DECLARE_TEST(t_bug33298)
+{
+  SQLRETURN rc= 0;
+  expect_stmt(hstmt, SQLProcedureColumns(hstmt, 0, NULL, 0, NULL,
+                                         0, NULL, 0, NULL),
+                                         SQL_SUCCESS_WITH_INFO);
+  rc= SQLFetch(hstmt);
+  /**
+    SQL_NO_DATA is ok for the current implementation,
+    SQL_SUCCESS should be ok for when SQLProcedureColumns is implemented
+  */
+  if (rc == SQL_ERROR)
+    return FAIL;
+
+  return OK;
+}
+
+
+/**
+ Bug #12805: ADO failed to retrieve the length of LONGBLOB columns
+*/
+DECLARE_TEST(t_bug12805)
+{
+  SQLHENV    henv1;
+  SQLHDBC    hdbc1;
+  SQLHSTMT   hstmt1;
+  SQLULEN    length;  
+  SQLUINTEGER len2;
+
+  SET_DSN_OPTION(1 << 27);
+
+  alloc_basic_handles(&henv1, &hdbc1, &hstmt1);
+
+  ok_sql(hstmt1, "DROP TABLE IF EXISTS bug12805");
+  ok_sql(hstmt1, "CREATE TABLE bug12805("\
+                 "id INT PRIMARY KEY auto_increment,"\
+                 "longdata LONGBLOB NULL)");
+
+  ok_stmt(hstmt1, SQLColumns(hstmt1, NULL, 0, NULL, 0,
+                             (SQLCHAR *)"bug12805", SQL_NTS,
+                             (SQLCHAR *)"longdata", SQL_NTS));
+
+  ok_stmt(hstmt1, SQLFetch(hstmt1));
+  ok_stmt(hstmt1, SQLGetData(hstmt1, 7, SQL_C_ULONG, &len2,
+                             0, NULL));
+  is_num(len2, 2147483647);
+  ok_stmt(hstmt1, SQLFreeStmt(hstmt1, SQL_CLOSE));
+
+  length= 0;
+  ok_sql(hstmt1, "SELECT * FROM bug12805");
+  ok_stmt(hstmt1, SQLDescribeCol(hstmt1, 2, NULL, NULL, NULL, NULL,
+                                 &length, NULL, NULL));
+  is_num(length, 2147483647);
+
+  ok_stmt(hstmt1, SQLFreeStmt(hstmt1, SQL_CLOSE));
+  free_basic_handles(&henv1, &hdbc1, &hstmt1);
+
+  /* Check without the 32-bit signed flag */
+  ok_stmt(hstmt, SQLColumns(hstmt, NULL, 0, NULL, 0,
+                            (SQLCHAR *)"bug12805", SQL_NTS,
+                            (SQLCHAR *)"longdata", SQL_NTS));
+
+  ok_stmt(hstmt, SQLFetch(hstmt));
+  ok_stmt(hstmt, SQLGetData(hstmt, 7, SQL_C_ULONG, &len2,
+                            0, NULL));
+  is_num(len2, 4294967295);
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+
+  length= 0;
+  ok_sql(hstmt, "SELECT * FROM bug12805");
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 2, NULL, NULL, NULL, NULL,
+                                 &length, NULL, NULL));
+  is_num(length, 4294967295);
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+  ok_sql(hstmt, "DROP TABLE bug12805");
+
+  SET_DSN_OPTION(0);
+  return OK;
+}
+
+
+/**
+ Bug #30770: Access Violation in myodbc3.dll
+*/
+DECLARE_TEST(t_bug30770)
+{
+  SQLCHAR    buff[512];
+  SQLHENV    henv1;
+  SQLHDBC    hdbc1;
+  SQLHSTMT   hstmt1;
+  SQLCHAR    conn[MAX_NAME_LEN];
+
+
+  ok_sql(hstmt, "DROP TABLE IF EXISTS bug30770");
+  ok_sql(hstmt, "CREATE TABLE bug30770 (a INT)");
+
+  /* Connect with no default daabase */
+  sprintf((char *)conn, "DRIVER=%s;SERVER=%s;" \
+                        "UID=%s;PASSWORD=%s", mydriver, myserver, myuid, mypwd);
+  if (mysock != NULL)
+  {
+    strcat((char *)conn, ";SOCKET=");
+    strcat((char *)conn, (char *)mysock);
+  }
+  if (myport)
+  {
+    char pbuff[20];
+    sprintf(pbuff, ";PORT=%d", myport);
+    strcat((char *)conn, pbuff);
+  }
+  is(mydrvconnect(&henv1, &hdbc1, &hstmt1, conn) == OK);
+
+  sprintf((char *)buff, "USE %s;", mydb);
+  ok_stmt(hstmt1, SQLExecDirect(hstmt1, buff, SQL_NTS));
+
+  /* Get the info from just one table.  */
+  ok_stmt(hstmt1, SQLColumns(hstmt1, NULL, SQL_NTS, NULL, SQL_NTS, "bug30770",
+                            SQL_NTS, NULL, 0));
+
+  ok_stmt(hstmt1, SQLFetch(hstmt1));
+
+  is_str(my_fetch_str(hstmt1, buff, 3), "bug30770", 9);
+  is_str(my_fetch_str(hstmt1, buff, 4), "a", 1);
+
+  expect_stmt(hstmt1, SQLFetch(hstmt1), SQL_NO_DATA_FOUND);
+  free_basic_handles(&henv1, &hdbc1, &hstmt1);
+
+  ok_sql(hstmt, "DROP TABLE bug30770");
+  return OK;
+}
+
+
 BEGIN_TESTS
   ADD_TEST(my_columns_null)
   ADD_TEST(my_drop_table)
@@ -1149,6 +1343,11 @@ BEGIN_TESTS
   ADD_TEST(t_bug26934)
   ADD_TEST(t_bug29888)
   ADD_TEST(t_bug14407)
+  ADD_TEST(t_bug32864)
+  ADD_TEST(t_bug32989)
+  ADD_TEST(t_bug33298)
+  ADD_TEST(t_bug12805)
+  ADD_TEST(t_bug30770)
 END_TESTS
 
 
