@@ -130,7 +130,7 @@ DECLARE_TEST(t_tstotime)
     ts.second = 45;
     ts.fraction = 05;   
 
-    tmysql_exec(hstmt,"drop table t_tstotime");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_tstotime");
 
     rc = SQLTransact(NULL,hdbc,SQL_COMMIT);
     mycon(hdbc,rc);
@@ -183,6 +183,8 @@ DECLARE_TEST(t_tstotime)
     rc = SQLFreeStmt(hstmt,SQL_CLOSE);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_tstotime");
+
   return OK;
 }
 
@@ -225,6 +227,8 @@ DECLARE_TEST(t_tstotime1)
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_RESET_PARAMS));
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_tstotime1");
+
   return OK;
 }
 
@@ -279,7 +283,7 @@ DECLARE_TEST(t_time)
   SQL_TIME_STRUCT tm;
   SQLCHAR         str[20];
 
-    tmysql_exec(hstmt,"drop table t_time");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_time");
     rc = tmysql_exec(hstmt,"create table t_time(tm time, ts timestamp(14))");
     mystmt(hstmt,rc);
 
@@ -333,6 +337,8 @@ DECLARE_TEST(t_time)
     rc = SQLFreeStmt(hstmt,SQL_CLOSE);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_time");
+
   return OK;
 }
 
@@ -345,7 +351,7 @@ DECLARE_TEST(t_time1)
   SQLCHAR         data[30];
   SQLLEN          length;
 
-    SQLExecDirect(hstmt,"drop table t_time",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_time");
     rc = SQLExecDirect(hstmt,"create table t_time(t time, t1 timestamp, t2 datetime, t3 date)",SQL_NTS);
     mystmt(hstmt,rc);
 
@@ -602,6 +608,8 @@ DECLARE_TEST(t_time1)
     SQLFreeStmt(hstmt, SQL_UNBIND);
     SQLFreeStmt(hstmt, SQL_CLOSE);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_time");
+
   return OK;
 }
 
@@ -813,6 +821,7 @@ DECLARE_TEST(t_datecolumns)
 DECLARE_TEST(t_bug14414)
 {
   SQLCHAR col[10];
+  SQLSMALLINT nullable;
 
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug14414");
   ok_sql(hstmt, "CREATE TABLE t_bug14414(a TIMESTAMP, b TIMESTAMP NOT NULL,"
@@ -840,11 +849,82 @@ DECLARE_TEST(t_bug14414)
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
+  /**
+    Bug #26108  MyODBC ADO field attributes reporting adFldMayBeNull for
+    not null columns
+  */
+  ok_sql(hstmt, "SELECT * FROM t_bug14414");
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 1, NULL, 0, NULL, NULL, NULL, NULL,
+                                &nullable));
+  is_num(nullable, SQL_NULLABLE);
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 2, NULL, 0, NULL, NULL, NULL, NULL,
+                                &nullable));
+  is_num(nullable, SQL_NO_NULLS);
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 3, NULL, 0, NULL, NULL, NULL, NULL,
+                                &nullable));
+  is_num(nullable, SQL_NULLABLE);
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug14414");
   return OK;
 }
 
 
+/**
+ Bug #30939: SQLGetTypeInfo returns 6 instead of 8 for COLUMN_SIZE for
+ SQL_TYPE_TIME
+*/
+DECLARE_TEST(t_bug30939)
+{
+  ok_stmt(hstmt, SQLGetTypeInfo(hstmt, SQL_TYPE_TIME));
+
+  ok_stmt(hstmt, SQLFetch(hstmt));
+
+  is_num(my_fetch_int(hstmt, 3), 8);
+
+  expect_stmt(hstmt, SQLFetch(hstmt), SQL_NO_DATA);
+
+  return OK;
+}
+
+
+/**
+ Bug #31009: Wrong SQL_DESC_LITERAL_PREFIX for date-time types
+*/
+DECLARE_TEST(t_bug31009)
+{
+  SQLCHAR data[20];
+  SQLSMALLINT len;
+  SQLLEN dlen;
+
+  ok_sql(hstmt, "SELECT CAST('2007-01-13' AS DATE) AS col1");
+
+  ok_stmt(hstmt, SQLColAttribute(hstmt, 1, SQL_DESC_LITERAL_PREFIX,
+                                 data, sizeof(data), &len, NULL));
+  is_num(len, 1);
+  is_str(data, "'", 2);
+
+  ok_stmt(hstmt, SQLColAttribute(hstmt, 1, SQL_DESC_LITERAL_SUFFIX,
+                                 data, sizeof(data), &len, NULL));
+  is_num(len, 1);
+  is_str(data, "'", 2);
+
+  ok_stmt(hstmt, SQLFetch(hstmt));
+
+  ok_stmt(hstmt, SQLGetData(hstmt, 1, SQL_C_CHAR, data, sizeof(data), &dlen));
+  is_num(dlen, 10);
+  is_str(data, "2007-01-13", 11);
+
+  expect_stmt(hstmt, SQLFetch(hstmt), SQL_NO_DATA_FOUND);
+
+  return OK;
+}
+
+
 BEGIN_TESTS
   ADD_TEST(my_ts)
   ADD_TEST(t_tstotime)
@@ -858,6 +938,8 @@ BEGIN_TESTS
   ADD_TODO(t_bug30081)
   ADD_TEST(t_datecolumns)
   ADD_TEST(t_bug14414)
+  ADD_TEST(t_bug30939)
+  ADD_TEST(t_bug31009)
 END_TESTS
 
 
