@@ -222,6 +222,8 @@ DECLARE_TEST(t_warning)
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_UNBIND));
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_warning");
+
   return OK;
 }
 
@@ -311,6 +313,16 @@ DECLARE_TEST(getdata_need_nullind)
 }
 
 
+/**
+ Bug #27158: MyODBC 3.51/ ADO cmd option adCmdUnknown won't work for tables - regression
+*/
+DECLARE_TEST(t_bug27158)
+{
+  expect_sql(hstmt, "{ CALL test.does_not_exist }", SQL_ERROR);
+  return check_sqlstate(hstmt, "42000");
+}
+
+
 BEGIN_TESTS
 #ifndef NO_DRIVERMANAGER
   ADD_TEST(t_odbc2_error)
@@ -320,10 +332,11 @@ BEGIN_TESTS
 #endif
   ADD_TEST(t_diagrec)
   ADD_TEST(t_warning)
-  ADD_TODO(t_bug3456)
+  ADD_TEST(t_bug3456)
   ADD_TEST(t_bug16224)
   ADD_TEST(bind_invalidcol)
   ADD_TEST(getdata_need_nullind)
+  ADD_TEST(t_bug27158)
 END_TESTS
 
 RUN_TESTS
