@@ -25,8 +25,7 @@
 /* Testing basic scrolling feature */
 DECLARE_TEST(t_scroll)
 {
-    SQLRETURN rc;
-    SQLUINTEGER i;
+  SQLUINTEGER i;
 
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_scroll");
   ok_sql(hstmt, "CREATE TABLE t_scroll (col1 INT)");
@@ -122,14 +121,14 @@ DECLARE_TEST(t_array_relative_10)
 {
     SQLRETURN rc;
     SQLINTEGER iarray[15];
-    SQLLEN   nrows;
-    SQLUINTEGER i,index;
+    SQLLEN   nrows, index;
+    SQLUINTEGER i;
     char name[21];
 
     ok_stmt(hstmt, SQLSetStmtAttr(hstmt, SQL_ATTR_CURSOR_TYPE,
                                   (SQLPOINTER)SQL_CURSOR_STATIC, 0));
 
-    SQLExecDirect(hstmt,"drop table t_array_relative_10",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_array_relative_10");
 
     rc = SQLExecDirect(hstmt,"create table t_array_relative_10(id int,name char(20))",SQL_NTS);
     mystmt(hstmt,rc);
@@ -258,6 +257,8 @@ DECLARE_TEST(t_array_relative_10)
     rc = SQLSetStmtAttr(hstmt,SQL_ATTR_ROW_ARRAY_SIZE,(SQLPOINTER)1,0);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_array_relative_10");
+
   return OK;
 }
 
@@ -268,12 +269,12 @@ DECLARE_TEST(t_relative_1)
     SQLRETURN rc;
     SQLLEN nrows;
     SQLUINTEGER i;
-    const int max_rows=10;
+    const SQLUINTEGER max_rows=10;
 
     ok_stmt(hstmt, SQLSetStmtAttr(hstmt, SQL_ATTR_CURSOR_TYPE,
                                   (SQLPOINTER)SQL_CURSOR_STATIC, 0));
 
-    SQLExecDirect(hstmt,"drop table t_relative_1",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_relative_1");
 
     rc = SQLExecDirect(hstmt,"create table t_relative_1(id int)",SQL_NTS);
     mystmt(hstmt,rc);
@@ -467,6 +468,8 @@ DECLARE_TEST(t_relative_1)
     rc = SQLSetStmtAttr(hstmt,SQL_ATTR_ROW_ARRAY_SIZE,(SQLPOINTER)1,0);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_relative_1");
+
   return OK;
 }
 
@@ -478,12 +481,12 @@ DECLARE_TEST(t_array_relative_2)
     SQLUINTEGER i;
     SQLLEN nrows;
     SQLINTEGER iarray[15];
-    const int max_rows=10;
+    const SQLUINTEGER max_rows=10;
 
     ok_stmt(hstmt, SQLSetStmtAttr(hstmt, SQL_ATTR_CURSOR_TYPE,
                                   (SQLPOINTER)SQL_CURSOR_STATIC, 0));
 
-    SQLExecDirect(hstmt,"drop table t_array_relative_2",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_array_relative_2");
 
     rc = SQLExecDirect(hstmt,"create table t_array_relative_2(id int)",SQL_NTS);
     mystmt(hstmt,rc);
@@ -779,6 +782,8 @@ DECLARE_TEST(t_array_relative_2)
     rc = SQLSetStmtAttr(hstmt,SQL_ATTR_ROW_ARRAY_SIZE,(SQLPOINTER)1,0);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_array_relative_2");
+
   return OK;
 }
 
@@ -789,12 +794,12 @@ DECLARE_TEST(t_absolute_1)
     SQLRETURN rc;
     SQLLEN nrows;
     SQLUINTEGER i;
-    const int max_rows=10;
+    const SQLUINTEGER max_rows=10;
 
     ok_stmt(hstmt, SQLSetStmtAttr(hstmt, SQL_ATTR_CURSOR_TYPE,
                                   (SQLPOINTER)SQL_CURSOR_STATIC, 0));
 
-    SQLExecDirect(hstmt,"drop table t_absolute_1",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_absolute_1");
 
     rc = SQLExecDirect(hstmt,"create table t_absolute_1(id int)",SQL_NTS);
     mystmt(hstmt,rc);
@@ -963,6 +968,8 @@ DECLARE_TEST(t_absolute_1)
     rc = SQLSetStmtAttr(hstmt,SQL_ATTR_ROW_ARRAY_SIZE,(SQLPOINTER)1,0);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_absolute_1");
+
   return OK;
 }
 
@@ -973,13 +980,13 @@ DECLARE_TEST(t_absolute_2)
     SQLRETURN rc;
     SQLLEN nrows;
     SQLINTEGER iarray[15];
-    const int max_rows=10;
+    const SQLUINTEGER max_rows=10;
     SQLUINTEGER i;
 
     ok_stmt(hstmt, SQLSetStmtAttr(hstmt, SQL_ATTR_CURSOR_TYPE,
                                   (SQLPOINTER)SQL_CURSOR_STATIC, 0));
 
-    SQLExecDirect(hstmt,"drop table t_absolute_2",SQL_NTS);
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_absolute_2");
 
     rc = SQLExecDirect(hstmt,"create table t_absolute_2(id int)",SQL_NTS);
     mystmt(hstmt,rc);
@@ -1218,6 +1225,8 @@ DECLARE_TEST(t_absolute_2)
     rc = SQLSetStmtAttr(hstmt,SQL_ATTR_ROW_ARRAY_SIZE,(SQLPOINTER)1,0);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_absolute_2");
+
   return OK;
 }
 
@@ -1225,8 +1234,8 @@ DECLARE_TEST(t_absolute_2)
 BEGIN_TESTS
   ADD_TEST(t_scroll)
   ADD_TEST(t_array_relative_10)
-  ADD_TEST(t_relative_1)
   ADD_TEST(t_array_relative_2)
+  ADD_TEST(t_relative_1)
   ADD_TEST(t_absolute_1)
   ADD_TEST(t_absolute_2)
 END_TESTS
