@@ -25,7 +25,7 @@
 
 DECLARE_TEST(t_longlong1)
 {
-#if SQLBIGINT_MADE_PORTABLE
+#if SQLBIGINT_MADE_PORTABLE || defined(_WIN32)
   SQLBIGINT session_id, ctn;
 
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_longlong");
@@ -64,7 +64,7 @@ DECLARE_TEST(t_longlong1)
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
   ok_sql(hstmt, "DROP TABLE IF EXISTS t_longlong");
-#endif
+#endif /* SQLBIGINT_MADE_PORTABLE || defined(_WIN32) */
 
   return OK;
 }
@@ -133,7 +133,7 @@ DECLARE_TEST(t_decimal)
   SQLINTEGER      i_data=189, l_data=-23;
   SQLRETURN       rc;
 
-    tmysql_exec(hstmt,"drop table t_decimal");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_decimal");
     rc = tmysql_exec(hstmt,"create table t_decimal(d1 decimal(10,6))");
     mystmt(hstmt,rc);
 
@@ -215,13 +215,15 @@ DECLARE_TEST(t_decimal)
     rc = SQLFreeStmt(hstmt,SQL_CLOSE);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_decimal");
+
   return OK;
 }
 
 
 DECLARE_TEST(t_bigint)
 {
-#if SQLBIGINT_MADE_PORTABLE
+#if SQLBIGINT_MADE_PORTABLE || defined(_WIN32)
     SQLRETURN rc;
     SQLLEN nlen = 4;
     union {                    /* An union to get 4 byte alignment */
@@ -336,7 +338,7 @@ DECLARE_TEST(t_bigint)
     rc = SQLFreeStmt(hstmt,SQL_CLOSE);
     mystmt(hstmt,rc);
 
-#endif
+#endif /* SQLBIGINT_MADE_PORTABLE || defined(_WIN32) */
   return OK;
 }
 
@@ -347,7 +349,7 @@ DECLARE_TEST(t_enumset)
     SQLCHAR szEnum[40]="MYSQL_E1";
     SQLCHAR szSet[40]="THREE,ONE,TWO";
 
-    tmysql_exec(hstmt,"drop table t_enumset");
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_enumset");
 
     rc = SQLTransact(NULL,hdbc,SQL_COMMIT);
     mycon(hdbc,rc);
@@ -399,6 +401,8 @@ DECLARE_TEST(t_enumset)
     rc = SQLFreeStmt(hstmt,SQL_CLOSE);
     mystmt(hstmt,rc);
 
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_enumset");
+
   return OK;
 }
 
@@ -565,7 +569,7 @@ DECLARE_TEST(decimal_scale)
   ok_stmt(hstmt, SQLColAttribute(hstmt, 1, SQL_DESC_FIXED_PREC_SCALE,
                                  NULL, 0, NULL, &fixed));
 
-  is_num(fixed, SQL_TRUE);
+  is_num(fixed, SQL_FALSE);
 
   ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
 
@@ -661,7 +665,7 @@ DECLARE_TEST(bit)
 
   is_str(my_fetch_str(hstmt, col, 4), "b", 1);
   is_num(my_fetch_int(hstmt, 5), SQL_BINARY); /* DATA_TYPE */
-  is_num(my_fetch_int(hstmt, 7), 6); /* COLUMN_SIZE */
+  is_num(my_fetch_int(hstmt, 7), 3); /* COLUMN_SIZE */
   is_num(my_fetch_int(hstmt, 8), 3); /* BUFFER_LENGTH */
   is_num(my_fetch_int(hstmt, 16), 3); /* CHAR_OCTET_LENGTH */
 
@@ -686,6 +690,99 @@ DECLARE_TEST(bit)
 }
 
 
+/**
+ Bug #32171: ODBC Driver incorrectly parses large Unsigned Integers
+*/
+DECLARE_TEST(t_bug32171)
+{
+  SQLUINTEGER in= 4255080020, out;
+  SQLCHAR buff[128];
+
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug32171");
+  ok_sql(hstmt, "CREATE TABLE t_bug32171 (a INT UNSIGNED)");
+
+  sprintf((char *)buff, "INSERT INTO t_bug32171 VALUES ('%u')", in);
+  ok_stmt(hstmt, SQLExecDirect(hstmt, buff, SQL_NTS));
+
+  ok_sql(hstmt, "SELECT * FROM t_bug32171");
+
+  ok_stmt(hstmt, SQLBindCol(hstmt, 1, SQL_C_ULONG, &out, 0, NULL));
+  ok_stmt(hstmt, SQLFetch(hstmt));
+
+  is_num(out, in);
+
+  expect_stmt(hstmt, SQLFetch(hstmt), SQL_NO_DATA);
+
+  ok_stmt(hstmt, SQLFreeStmt(hstmt, SQL_CLOSE));
+
+  ok_sql(hstmt, "DROP TABLE IF EXISTS t_bug32171");
+
+  return OK;
+}
+
+
+/*
+  Bug #31220 - SQLFetch or SQLFetchScroll returns negative data length
+               when using SQL_C_WCHAR
+*/
+DECLARE_TEST(t_bug31220)
+{
+  SQLLEN outlen= 999;
+  SQLWCHAR outbuf[5];
+
+  /* the call sequence of this test is not allowed under a driver manager */
+  if (using_dm(hdbc))
+    return OK;
+
+  ok_sql(hstmt, "select 1");
+  ok_stmt(hstmt, SQLBindCol(hstmt, 1, 999 /* unknown type */,
+                            outbuf, 5, &outlen));
+  expect_stmt(hstmt, SQLFetch(hstmt), SQL_ERROR);
+  is(check_sqlstate(hstmt, "07006") == OK);
+  is_num(outlen, 999);
+  return OK;  
+}
+
+
+/**
+  Bug #29402: field type charset 63 problem
+*/
+DECLARE_TEST(t_bug29402)
+{
+  SQLSMALLINT name_length, data_type, decimal_digits, nullable;
+  SQLCHAR column_name[SQL_MAX_COLUMN_NAME_LEN];
+  SQLULEN column_size;
+  SQLHENV    henv1;
+  SQLHDBC    hdbc1;
+  SQLHSTMT   hstmt1;
+
+  /* First check how the option FLAG_NO_BINARY_RESULT works */
+  SET_DSN_OPTION(1 << 28);
+
+  alloc_basic_handles(&henv1, &hdbc1, &hstmt1);
+
+  ok_sql(hstmt1, "SELECT CONCAT('ABCDEFG', 20) concated");
+
+  ok_stmt(hstmt1, SQLDescribeCol(hstmt1, 1, column_name, sizeof(column_name),
+                                &name_length, &data_type, &column_size,
+                                &decimal_digits, &nullable));
+
+  is_num(data_type, SQL_VARCHAR);
+  ok_stmt(hstmt1, SQLFreeStmt(hstmt1, SQL_CLOSE));
+  free_basic_handles(&henv1, &hdbc1, &hstmt1);
+
+  /* Check without FLAG_NO_BINARY_RESULT */
+  ok_sql(hstmt, "SELECT CONCAT('ABCDEFG', 20) concated");
+
+  ok_stmt(hstmt, SQLDescribeCol(hstmt, 1, column_name, sizeof(column_name),
+                                &name_length, &data_type, &column_size,
+                                &decimal_digits, &nullable));
+
+  is_num(data_type, SQL_VARBINARY);
+  return OK;
+}
+
+
 BEGIN_TESTS
   ADD_TEST(t_longlong1)
   ADD_TEST(t_numeric)
@@ -700,6 +797,9 @@ BEGIN_TESTS
   ADD_TEST(binary_suffix)
   ADD_TEST(float_scale)
   ADD_TEST(bit)
+  ADD_TEST(t_bug32171)
+  ADD_TEST(t_bug31220)
+  ADD_TEST(t_bug29402)
 END_TESTS
 
 
