@@ -35,11 +35,7 @@ DECLARE_TEST(t_odbc3_envattr)
     rc = SQLGetEnvAttr(henv1,SQL_ATTR_ODBC_VERSION,(SQLPOINTER)&ov_version,0,0);
     myenv(henv1,rc);
     printMessage("default odbc version:%d\n",ov_version);
-#ifdef _WIN32
-    my_assert(ov_version == SQL_OV_ODBC3);
-#else
-    my_assert(ov_version == SQL_OV_ODBC2);
-#endif
+    is_num(ov_version, SQL_OV_ODBC2);
 
     rc = SQLSetEnvAttr(henv1,SQL_ATTR_ODBC_VERSION,(SQLPOINTER)SQL_OV_ODBC3,0);
     myenv(henv1,rc);
@@ -126,14 +122,20 @@ DECLARE_TEST(t_driver_connect)
     rc = SQLAllocConnect(henv1,&hdbc1);
     myenv(henv1,rc);
 
-    sprintf(conn_in,"DRIVER={MySQL ODBC 3.51 Driver};USER=%s;PASSWORD=%s;"
+    sprintf(conn_in,"DRIVER=%s;USER=%s;PASSWORD=%s;"
                     "DATABASE=%s;SERVER=%s;OPTION=3;STMT=use mysql",
-            myuid, mypwd, mydb, myserver);
+            mydriver, myuid, mypwd, mydb, myserver);
     if (mysock != NULL)
     {
       strcat(conn_in, ";SOCKET=");
       strcat(conn_in, mysock);
     }
+    if (myport)
+    {
+      char pbuff[20];
+      sprintf(pbuff, ";PORT=%d", myport);
+      strcat((char *)conn_in, pbuff);
+    }
     rc = SQLDriverConnect(hdbc1, (SQLHWND)0, conn_in, sizeof(conn_in),
                           conn_out, sizeof(conn_out), &conn_out_len,
                           SQL_DRIVER_NOPROMPT);
