@@ -56,11 +56,26 @@
 #define TRUE 1
 #endif
 
-#ifndef max
-#define max( a, b ) (((a) > (b)) ? (a) : (b))
-#define min( a, b ) (((a) < (b)) ? (a) : (b))
+#ifndef myodbc_max
+#define myodbc_max( a, b ) (((a) > (b)) ? (a) : (b))
+#define myodbc_min( a, b ) (((a) < (b)) ? (a) : (b))
 #endif
 
+
+/*
+   Most of the installer API functions in iODBC incorrectly reset the
+   config mode, so we need to save and restore it whenever we call those
+   functions. These macros reduce the clutter a little bit.
+*/
+#if USE_IODBC
+# define SAVE_MODE() UWORD config_mode; (void)SQLGetConfigMode(&config_mode)
+# define RESTORE_MODE() (void)SQLSetConfigMode(config_mode)
+#else
+# define SAVE_MODE()
+# define RESTORE_MODE()
+#endif
+
+
 /* Could use DRIVER_NAME but trying to keep dependency upon driver specific code to a min */
 #define MYODBCINST_DRIVER_NAME "MySQL ODBC 3.51 Driver"
 
@@ -181,7 +196,10 @@ typedef struct tMYODBCUTIL_DATASOURCE
     char *pszSSLCA;             /* pathname to SSL certificate authority file                                                                  */
     char *pszSSLCAPATH;         /* pathname to a directory that contains SSL ceritificate authority files                                      */
     char *pszSSLCIPHER;         /* pathname to a list of allowable ciphers                                                                    */
+    char *pszSSLVERIFY;         /* verify server certificate (see --ssl-verify-server-cert                                      */
     char *pszCHARSET;           /* default charset to use for connection */
+    char *pszREADTIMEOUT;       /* connection read timeout (see mysql_options / MYSQL_OPT_READ_TIMEOUT */
+    char *pszWRITETIMEOUT;      /* connection write timeout (see mysql_options / MYSQL_OPT_WRITE_TIMEOUT */
 
     MYODBCUTIL_DATASOURCE_MODE      nMode;      /* ConfigDSN mode or SQLDriverConnect mode.                                     */
     MYODBCUTIL_DATASOURCE_CONNECT   nConnect;   /* SQLDriverConnect() using a DSN or a DRIVER to connect.                       */
@@ -252,3 +270,4 @@ BOOL                    MYODBCUtilInsertStr( char *pszStr, LPCSTR pszStrIn, SQLS
 #endif
 
 
+
