@@ -83,6 +83,16 @@ void MYODBCUtilClearDataSource( MYODBCUTIL_DATASOURCE *pDataSource )
         _global_free( pDataSource->pszUSER );
         pDataSource->pszUSER = NULL;
     }
+    if ( pDataSource->pszREADTIMEOUT )
+    {
+        _global_free( pDataSource->pszREADTIMEOUT );
+        pDataSource->pszREADTIMEOUT = NULL;
+    }
+    if ( pDataSource->pszWRITETIMEOUT )
+    {
+        _global_free( pDataSource->pszWRITETIMEOUT );
+        pDataSource->pszWRITETIMEOUT = NULL;
+    }
 
 	if( pDataSource->pszSSLCA)
 	{
@@ -104,6 +114,11 @@ void MYODBCUtilClearDataSource( MYODBCUTIL_DATASOURCE *pDataSource )
 		_global_free (pDataSource->pszSSLCIPHER);
 		pDataSource->pszSSLCIPHER = NULL;
 	}
+    if( pDataSource->pszSSLVERIFY)
+    {
+        _global_free (pDataSource->pszSSLVERIFY);
+        pDataSource->pszSSLVERIFY = NULL;
+    }
 	if( pDataSource->pszSSLKEY)
 	{
 		_global_free (pDataSource->pszSSLKEY);
