@@ -46,9 +46,12 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
     char *  pszEntryName;
     char    szValue[4096];
     int     nChars;
-#if defined(WIN32)
+#ifdef _WIN32
     UWORD   nMode   = ODBC_BOTH_DSN;
+#endif
+    SAVE_MODE();
 
+#ifdef _WIN32
     if ( !SQLGetConfigMode( &nMode ) )
     {
         fprintf( stderr, "[%s][%d][ERROR] SQLGetConfigMode failed!\n", __FILE__, __LINE__ );
@@ -62,10 +65,13 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
     *szEntryNames = '\0';
 
     /* Get the list of key names for the DSN's section. */
-    if ( ( nChars = SQLGetPrivateProfileString( pszDSN, NULL, "", szEntryNames, sizeof( szEntryNames ) - 1, "ODBC.INI" ) ) < 1 )
-    {
-        return FALSE;
-    }
+    nChars= SQLGetPrivateProfileString(pszDSN, NULL, "",
+                                       szEntryNames, sizeof(szEntryNames) - 1,
+                                       "ODBC.INI");
+    if (nChars < 1)
+      return FALSE;
+
+    RESTORE_MODE();
 
 #if defined(WIN32)
     {
@@ -211,11 +217,26 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
                 if ( !pDataSource->pszSSLKEY )
                     pDataSource->pszSSLKEY = _global_strdup( szValue );
             }
+            else if ( strcasecmp( pszEntryName, "SSLVERIFY" ) == 0 )
+            {    
+                if ( !pDataSource->pszSSLVERIFY )
+                    pDataSource->pszSSLVERIFY = _global_strdup( szValue );
+            }
             else if (strcasecmp(pszEntryName, "CHARSET") == 0)
             {
               if (!pDataSource->pszCHARSET)
                 pDataSource->pszCHARSET= _global_strdup(szValue);
             }
+            else if (strcasecmp(pszEntryName, "READTIMEOUT") == 0)
+            {
+              if (!pDataSource->pszREADTIMEOUT)
+                pDataSource->pszREADTIMEOUT= _global_strdup(szValue);
+            }
+            else if (strcasecmp(pszEntryName, "WRITETIMEOUT") == 0)
+            {
+              if (!pDataSource->pszWRITETIMEOUT)
+                pDataSource->pszWRITETIMEOUT= _global_strdup(szValue);
+            }
             else
             {
                 /* What the ? */
@@ -234,6 +255,8 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
             */    
         }
 
+        RESTORE_MODE();
+
         pszEntryName += strlen( pszEntryName ) + 1;
     } /* while */
 
@@ -243,9 +266,11 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
     {
         if ( SQLGetPrivateProfileString( MYODBCUTIL_ODBCINI_HEADER_SECTION, "", "", szEntryNames, sizeof( szEntryNames ) - 1, "ODBC.INI" ) < 1 )
         {
-            return FALSE;
+          return FALSE;
         }
 
+        RESTORE_MODE();
+
         pszEntryName = szEntryNames;
         while ( *pszEntryName )
         {
@@ -257,6 +282,7 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
                     pDataSource->pszDRIVER = _global_strdup( szValue );
                 }
             }
+            RESTORE_MODE();
             pszEntryName += strlen( pszEntryName ) + 1;
         }
     }
@@ -279,3 +305,4 @@ BOOL MYODBCUtilReadDataSource( MYODBCUTIL_DATASOURCE *pDataSource, LPCSTR pszDSN
     return TRUE;
 }
 
+
