@@ -29,7 +29,7 @@ char *myodbc_strndup( const char *s, size_t n )
     if ( !s )
         return 0;
 
-    nAvail = min( strlen(s) + 1, n + 1 );
+    nAvail = myodbc_min( strlen(s) + 1, n + 1 );
 
     if ( nAvail < 1 )
         return 0;
@@ -63,7 +63,7 @@ char *strnglobaldup( const char *s, size_t n )
     if ( !s )
         return 0;
 
-    nAvail = min( strlen(s) + 1, n + 1 );
+    nAvail = myodbc_min( strlen(s) + 1, n + 1 );
 
     if ( nAvail < 1 )
         return 0;
@@ -282,6 +282,11 @@ BOOL MYODBCUtilReadDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTIL
                             if ( !pDataSource->pszSSLKEY )
                                 pDataSource->pszSSLKEY = (char *)_global_strndup( pAnchorChar, pScanChar - pAnchorChar );
                         }
+                        else if ( strcasecmp( pszName, "SSLVERIFY" ) == 0 )
+                        {
+                            if ( !pDataSource->pszSSLVERIFY )
+                                pDataSource->pszSSLVERIFY = (char *)_global_strndup( pAnchorChar, pScanChar - pAnchorChar );
+                        }
                         else if (strcasecmp(pszName, "CHARSET") == 0)
                         {
                           if (!pDataSource->pszCHARSET)
@@ -290,6 +295,22 @@ BOOL MYODBCUtilReadDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTIL
                                                         pScanChar -
                                                         pAnchorChar);
                         }
+                        else if (strcasecmp(pszName, "READTIMEOUT") == 0)
+                        {
+                          if (!pDataSource->pszREADTIMEOUT)
+                              pDataSource->pszREADTIMEOUT=
+                                (char *)_global_strndup(pAnchorChar,
+                                                        pScanChar -
+                                                        pAnchorChar);
+                        }
+                        else if (strcasecmp(pszName, "WRITETIMEOUT") == 0)
+                        {
+                          if (!pDataSource->pszWRITETIMEOUT)
+                              pDataSource->pszWRITETIMEOUT=
+                                (char *)_global_strndup(pAnchorChar,
+                                                        pScanChar -
+                                                        pAnchorChar);
+                        }
                         else
                         {
                             fprintf( stderr, "[%s][%d][ERROR] Unhandled attribute (%s).\n", __FILE__, __LINE__, pszName );
@@ -325,3 +346,4 @@ BOOL MYODBCUtilReadDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTIL
 }
 
 
+
