@@ -212,6 +212,16 @@ BOOL MYODBCUtilWriteDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTI
             return FALSE;
     }
 
+    if ( pDataSource->pszSSLVERIFY )
+    {
+        MYODBCUTILWRITEDATASOURCESTR_DELIM;
+
+        if ( !MYODBCUtilInsertStr( pszStr, "SSLVERIFY=", nMaxLen, &nIndex ) )
+            return FALSE;
+        if ( !MYODBCUtilInsertStr( pszStr, pDataSource->pszSSLVERIFY, nMaxLen, &nIndex ) )
+            return FALSE;
+    }
+
     if (pDataSource->pszCHARSET)
     {
       MYODBCUTILWRITEDATASOURCESTR_DELIM;
@@ -223,6 +233,28 @@ BOOL MYODBCUtilWriteDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTI
         return FALSE;
     }
 
+    if (pDataSource->pszREADTIMEOUT)
+    {
+      MYODBCUTILWRITEDATASOURCESTR_DELIM;
+
+      if (!MYODBCUtilInsertStr(pszStr, "READTIMEOUT=", nMaxLen, &nIndex))
+        return FALSE;
+      if (!MYODBCUtilInsertStr(pszStr, pDataSource->pszREADTIMEOUT, nMaxLen,
+                               &nIndex))
+        return FALSE;
+    }
+
+    if (pDataSource->pszWRITETIMEOUT)
+    {
+      MYODBCUTILWRITEDATASOURCESTR_DELIM;
+
+      if (!MYODBCUtilInsertStr(pszStr, "WRITETIMEOUT=", nMaxLen, &nIndex))
+        return FALSE;
+      if (!MYODBCUtilInsertStr(pszStr, pDataSource->pszWRITETIMEOUT, nMaxLen,
+                               &nIndex))
+        return FALSE;
+    }
+
     if ( nDelim == MYODBCUTIL_DELIM_NULL )
     {
         MYODBCUTILWRITEDATASOURCESTR_DELIM;
@@ -233,3 +265,4 @@ BOOL MYODBCUtilWriteDataSourceStr( MYODBCUTIL_DATASOURCE *pDataSource, MYODBCUTI
 }
 
 
+
